{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "---\n",
    "title: \"📓 Week 08 - Student Notebook\"\n",
    "subtitle: \"Clustering using k-means and dbscan\"\n",
    "author: \"MY NAME (MY CANDIDATE NUMBER)\"\n",
    "---\n",
    "\n",
    "Let's start by loading the required libraries!"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 36,
   "metadata": {},
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "c:\\Users\\User\\AppData\\Local\\Programs\\Python\\Python313\\Lib\\site-packages\\tqdm\\auto.py:21: TqdmWarning: IProgress not found. Please update jupyter and ipywidgets. See https://ipywidgets.readthedocs.io/en/stable/user_install.html\n",
      "  from .autonotebook import tqdm as notebook_tqdm\n"
     ]
    },
    {
     "data": {
      "text/html": [
       "\n",
       "            <div id=\"WdP1tk\"></div>\n",
       "            <script type=\"text/javascript\" data-lets-plot-script=\"library\">\n",
       "                if(!window.letsPlotCallQueue) {\n",
       "                    window.letsPlotCallQueue = [];\n",
       "                }; \n",
       "                window.letsPlotCall = function(f) {\n",
       "                    window.letsPlotCallQueue.push(f);\n",
       "                };\n",
       "                (function() {\n",
       "                    var script = document.createElement(\"script\");\n",
       "                    script.type = \"text/javascript\";\n",
       "                    script.src = \"https://cdn.jsdelivr.net/gh/JetBrains/lets-plot@v4.5.1/js-package/distr/lets-plot.min.js\";\n",
       "                    script.onload = function() {\n",
       "                        window.letsPlotCall = function(f) {f();};\n",
       "                        window.letsPlotCallQueue.forEach(function(f) {f();});\n",
       "                        window.letsPlotCallQueue = [];\n",
       "                        \n",
       "                    };\n",
       "                    script.onerror = function(event) {\n",
       "                        window.letsPlotCall = function(f) {};    // noop\n",
       "                        window.letsPlotCallQueue = [];\n",
       "                        var div = document.createElement(\"div\");\n",
       "                        div.style.color = 'darkred';\n",
       "                        div.textContent = 'Error loading Lets-Plot JS';\n",
       "                        document.getElementById(\"WdP1tk\").appendChild(div);\n",
       "                    };\n",
       "                    var e = document.getElementById(\"WdP1tk\");\n",
       "                    e.appendChild(script);\n",
       "                })()\n",
       "            </script>\n",
       "            "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import numpy as np\n",
    "import pandas as pd\n",
    "from sklearn.cluster import KMeans, DBSCAN\n",
    "from sklearn.preprocessing import StandardScaler\n",
    "from sklearn.pipeline import Pipeline\n",
    "from umap import UMAP\n",
    "from lets_plot import *\n",
    "LetsPlot.setup_html()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Employing k-means on a two-dimensional customer segmentation data set (45 minutes)\n",
    "\n",
    "We will create a data frame object named `customers` that has two features\n",
    "\n",
    "  -   `income` shows income of customers in thousands of USD\n",
    "  -   `spending_score` provides a 0-100 index that compares spending amongst customers"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Open the data set, and select only the variables needed for the analysis"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Let's plot the correlation between both variables using a scatter plot."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Code here"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Looking at the graph, we can see that there are distinct segments of customers organised into somewhat distinct clusters.\n",
    "\n",
    "🗣️ **CLASSROOM DISCUSSION:**\n",
    "\n",
    "How many clusters do you see? Can you describe intuitively what each cluster represents?\n",
    "\n",
    "## Implementing k-means clustering\n",
    "\n",
    "Implementing k-means clustering in Python is fairly straightforward. We build a pipeline that standardises the data and instantiates a k-means model with 5 clusters. We then fit this pipeline to `customers`."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Instantiate a pipeline\n",
    "\n",
    "# Fit the model to the data\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "After this, we can create a new variable (`cluster`) by finding the vector of cluster assignments in `kclust_customers`, and converting the results into a factor. After that, we can use some simple modifications to our `ggplot` to see some results.\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Identify cluster labels for each row\n",
    "\n",
    "# Create a data frame based on customers by adding the cluster labels\n",
    "\n",
    "# Plot the results"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Validating k-means\n",
    "\n",
    "We can tell intuitively that 5 clusters probably makes the most sense. However, in most cases, we will not have the luxury of being able to do this, and will need to validate our choice of cluster number.\n",
    "\n",
    "### The elbow method\n",
    "\n",
    "One widely used method is the elbow method.  Simply put, when we see distinct \"elbows\" in the plot, we decide that adding more clusters will not result in a significant reduction in the total within-sum cluster sum of squared errors.  As a result, we can stop and use that many clusters.\n",
    "\n",
    "We can create an elbow plot using the nested tibble approach."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Create a function that returns inertia scores for a range of k\n",
    "def find_optimal_cluster(k, data):\n",
    "    # Create a pipeline that scales the data then fits k-means models over a range of k\n",
    "    pipe = Pipeline([(\"scaler\",StandardScaler()),(\"kmeans\",KMeans(n_clusters=k))])\n",
    "    # Fit the model to the data\n",
    "    pipe.fit(data)\n",
    "    # Return the inertia_ attribute\n",
    "    return pipe.named_steps[\"kmeans\"].inertia_\n",
    "\n",
    "# Create a data frame with the k range and associated inertia scores\n",
    "\n",
    "\n",
    "# Plot the output\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Is k-means clustering always the right choice?\n",
    "\n",
    "The answer is emphatically no.  Due to the fact that k-means clustering uses the distance between points to identify clusters, it will typically try to create evenly sized clusters when clusters should, in fact, be uneven. \n",
    "\n",
    "## Example 1: Odd conditional distributions"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Open the circles data\n",
    "\n",
    "\n",
    "# Plot x1 and x2 features in circles data\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Find the optimal number of clusters"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Create a data frame with the k range and associated inertia scores\n",
    "\n",
    "\n",
    "# Plot the output\n",
    "\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Run the model"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Instantiate model\n",
    "\n",
    "\n",
    "# Fit to the data\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Plot the results"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Code here"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "🗣️ **CLASSROOM DISCUSSION:**\n",
    "\n",
    "What went wrong?\n",
    "\n",
    "👉 **NOTE:** To see more about how different clustering algorithms produce different kinds of clusters in different scenarios, click [here](https://scikit-learn.org/1.5/modules/clustering.html).\n",
    "\n",
    "# Introducing DBSCAN (30 minutes)\n",
    "\n",
    "The DBSCAN algorithm overcomes some of the short-comings of the k-means algorithm by using the distance between nearest points.\n",
    "\n",
    "The below code will implement `dbscan`."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Instantiate a DBSCAN model\n",
    "\n",
    "\n",
    "# Fit the model to the data\n",
    "\n",
    "\n",
    "# Plot the results\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Applying dbscan to the customer segmentation data set\n",
    "\n",
    "Use `eps = 0.6` and `min_samples = 4` when applying dbscan to the customer segmentation data."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Create a pipeline that standardises the data and instantiates a DBSCAN\n",
    "\n",
    "\n",
    "# Fit the pipeline to the customers data\n",
    "\n",
    "\n",
    "# Retrieve the labels using a list comprehension\n",
    "\n",
    "\n",
    "# Create a list of outlier labels\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Try plotting the results yourself to see the differences."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Code here"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "👥 **DISCUSS IN PAIRS/GROUPS:**\n",
    "\n",
    "What difference in clustering do you see with dbscan?\n",
    "\n",
    "\n",
    "# Using DBSCAN with UMAP (15 minutes)\n",
    "\n",
    "You will remember from last week that we can employ Uniform Manifold Approximation and Projection (UMAP) to create two-dimensional representations of data.  With the Varieties of Democracy (V-Dem) data set, we found that employing UMAP led to several highly repressive regimes forming their own distinct cluster.  We can employ DBSCAN on the UMAP embeddings to find new insights into political regimes.\n",
    "\n",
    "**📝Task:** Let's load the data!"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 33,
   "metadata": {},
   "outputs": [],
   "source": [
    "vdem = pd.read_csv(\"../data/vdem-data-subset.csv\")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**📝Task:** Next, we can build a UMAP model, fit it to `vdem` and retrieve the embeddings."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 89,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Set a random seed\n",
    "np.random.seed(123)\n",
    "\n",
    "# Instantiate a UMAP with the relevant hyperparameter choice\n",
    "reducer = UMAP(n_neighbors=100)\n",
    "\n",
    "# Create a subset of the data using only variables beginning with \"v2x\"\n",
    "vdem_subset = vdem[vdem.columns[vdem.columns.str.contains(\"v2x\")]].to_numpy()\n",
    "\n",
    "# Fit / transform the model to the subset of data to obtain the embeddings\n",
    "embedding = reducer.fit_transform(vdem_subset)\n",
    "\n",
    "# Convert the embeddings to a data frame\n",
    "embedding = pd.DataFrame(embedding, columns = [\"first_dim\", \"second_dim\"])"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**📝Task:** After this, we can instantiate a DBSCAN, fit it to the embeddings, and plot the results.  Try experimenting with different combinations of minimum points and epsilon neighbourhood.\n",
    "\n",
    "**💡Hints:**\n",
    "-   If you are stuck with what hyperparameters to choose, try starting with `min_samples = 6` and `eps = 1.15`.\n",
    "-   Try experimenting with tooltips\n",
    "    -   Add the `country_year` labels from `vdem` to the embeddings data frame.\n",
    "    -   Instead of just adding a `geom_point` layer, try creating code that let's the `country_year` label for each row appear whenever you hover over it with your cursor (click [here](https://lets-plot.org/python/pages/api/lets_plot.layer_tooltips.html#lets_plot.layer_tooltips) for the relevant documentation)."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"hTjS65\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "   \n",
       "   (function() {\n",
       "   // ----------\n",
       "   \n",
       "   var containerDiv = document.getElementById(\"hTjS65\");\n",
       "   var observer = new ResizeObserver(function(entries) {\n",
       "       for (let entry of entries) {\n",
       "           var width = containerDiv.clientWidth\n",
       "           if (entry.contentBoxSize && width > 0) {\n",
       "           \n",
       "               // Render plot\n",
       "               if (observer) {\n",
       "                   observer.disconnect();\n",
       "                   observer = null;\n",
       "               }\n",
       "\n",
       "               var plotSpec={\n",
       "\"data\":{\n",
       "\"first_dim\":[5.779317378997803,5.770227909088135,5.7074785232543945,4.148795127868652,4.249514102935791,4.975675582885742,4.989107131958008,5.333121299743652,5.843827247619629,5.619314670562744,5.024075984954834,3.550023317337036,3.129648208618164,1.7882386445999146,11.0287504196167,10.827885627746582,10.767044067382813,10.775992393493652,10.762372970581055,10.864049911499023,10.884591102600098,10.78532886505127,10.591351509094238,9.205889701843262,10.748601913452148,10.777280807495117,11.49329662322998,10.789643287658691,16.704307556152344,16.762197494506836,16.78793716430664,16.8321475982666,16.905229568481445,16.936952590942383,16.949888229370117,17.001493453979492,16.963197708129883,17.055774688720703,17.08408546447754,17.093414306640625,17.128816604614258,16.917381286621094,15.458833694458008,15.458905220031738,15.458840370178223,15.471611022949219,15.448991775512695,15.410810470581055,15.405380249023438,15.413854598999023,15.435409545898438,15.40119457244873,15.462246894836426,15.458270072937012,15.45616340637207,15.478646278381348,9.716217994689941,9.702300071716309,9.699515342712402,9.669754981994629,9.645415306091309,9.65194320678711,9.618075370788574,9.621309280395508,9.609809875488281,9.592609405517578,9.575996398925781,5.2957024574279785,5.297855377197266,5.232911586761475,11.937151908874512,11.853728294372559,11.942072868347168,11.311988830566406,11.001949310302734,11.08677864074707,11.005182266235352,10.671673774719238,10.724190711975098,9.57749080657959,9.475226402282715,9.633358001708984,9.366802215576172,8.090868949890137,14.701401710510254,14.698742866516113,14.612791061401367,13.617318153381348,13.579702377319336,13.569965362548828,13.579214096069336,13.563859939575195,13.740691184997559,13.675044059753418,13.690560340881348,13.474529266357422,13.383098602294922,13.417499542236328,-6.25198221206665,-5.5500874519348145,-4.667487144470215,-3.4079573154449463,-3.28256893157959,-3.035700798034668,-2.046473979949951,-1.9996458292007446,-2.005927324295044,-1.3533780574798584,-1.358994722366333,-6.186150550842285,-6.212909698486328,-6.174563884735107,-4.446446418762207,-4.522863388061523,-4.6963019371032715,-4.7495574951171875,-5.226522922515869,-5.347641468048096,-5.325848579406738,-5.293438911437988,-5.286910533905029,-5.303197860717773,-4.715023994445801,-5.370290756225586,-5.889260292053223,-5.950469970703125,2.81166672706604,2.790494441986084,2.694683074951172,2.059725284576416,2.185823678970337,2.1343722343444824,2.152759313583374,2.2221434116363525,2.0517051219940186,1.855847954750061,2.3071155548095703,2.1798064708709717,1.9780009984970093,1.294776201248169,-6.695491790771484,-6.670297622680664,-5.456516742706299,-6.708264350891113,-6.833976745605469,-6.833327293395996,-6.696071624755859,-6.713115215301514,-6.6344146728515625,-6.4912872314453125,-6.508965969085693,-6.534145832061768,-6.520260334014893,-6.55166482925415,-5.10400390625,-4.460729598999023,-4.399689674377441,-4.718639850616455,-5.560484409332275,-6.791415691375732,-6.455305099487305,-6.436801433563232,-6.425085544586182,-6.456888675689697,-6.404965877532959,-6.4458513259887695,-6.501155853271484,-6.540104866027832,6.158847808837891,7.371267795562744,7.203435897827148,7.303257465362549,7.53567361831665,7.686654090881348,7.8595967292785645,7.840667247772217,7.646203517913818,6.812641143798828,6.4940972328186035,6.696353435516357,7.941910266876221,8.3683500289917,16.354270935058594,16.365901947021484,16.53585433959961,16.534883499145508,16.328996658325195,15.241006851196289,9.69686508178711,7.630049705505371,7.279581546783447,7.2849578857421875,4.965623378753662,3.6494555473327637,3.5413389205932617,3.8885109424591064,15.046648025512695,15.098090171813965,15.079869270324707,15.30374526977539,15.243921279907227,15.212011337280273,12.074974060058594,11.613184928894043,10.608861923217773,7.380923271179199,7.606948375701904,7.201547145843506,7.560883045196533,12.891958236694336,16.861003875732422,16.805177688598633,16.8172607421875,16.852252960205078,16.846559524536133,16.87689971923828,16.655040740966797,14.433793067932129,14.151788711547852,14.037602424621582,13.913847923278809,14.487004280090332,14.677613258361816,14.856739044189453,16.714557647705078,16.536466598510742,16.549434661865234,16.599220275878906,16.647388458251953,16.597482681274414,16.60528564453125,16.930269241333008,16.893112182617188,16.173328399658203,15.929361343383789,16.139381408691406,14.455228805541992,14.358563423156738,4.49229621887207,4.650428771972656,4.773952007293701,4.913450717926025,5.841399192810059,5.758769989013672,5.772420883178711,5.847987651824951,5.348114490509033,3.586132764816284,1.0152463912963867,-2.8882055282592773,-3.2456421852111816,-3.242751121520996,-3.3266043663024902,-3.371450901031494,-3.5002832412719727,-4.284156799316406,-5.749908924102783,-5.696636199951172,-5.701340198516846,-5.7342529296875,-6.000694751739502,-6.085298538208008,-6.036802768707275,-6.039408206939697,-6.048358917236328,-6.0726494789123535,6.940912246704102,6.93608283996582,6.890890598297119,6.796774387359619,6.751157283782959,4.35836124420166,4.496551990509033,4.246385097503662,3.4186878204345703,0.224267840385437,-2.316188335418701,3.40065598487854,3.2946107387542725,3.293703317642212,-1.590417742729187,-2.009697198867798,-1.8743715286254883,-1.9601011276245117,-1.95272958278656,-2.1807749271392822,-2.351750135421753,-2.2077255249023438,-2.0864901542663574,-2.572523832321167,-4.164727687835693,-3.9772768020629883,-6.621885776519775,-6.898113250732422,-1.4851009845733643,-1.2629649639129639,-1.3191769123077393,-1.249623417854309,-0.7448703050613403,-1.133953332901001,-1.0008561611175537,-1.3232430219650269,-2.226933717727661,-2.0862114429473877,-2.0789449214935303,-1.7905876636505127,2.2525038719177246,1.8471797704696655,3.9212968349456787,3.9293205738067627,-2.0823819637298584,-2.7950570583343506,1.6485943794250488,1.9595528841018677,1.9659526348114014,1.2669557332992554,1.0114059448242188,0.9916355609893799,-2.323918342590332,-4.242260456085205,-4.343268394470215,-4.465996265411377,-0.19473101198673248,-0.2357344925403595,-0.21491745114326477,-0.180744931101799,-0.1516883820295334,-0.7595778703689575,-1.291943073272705,-1.3873714208602905,-1.7200840711593628,-2.2525546550750732,-1.945993185043335,-1.8471094369888306,-2.0051684379577637,-2.7262868881225586,12.852519989013672,13.42806339263916,13.604135513305664,13.50806713104248,13.506097793579102,13.468993186950684,12.69286823272705,12.826460838317871,13.660623550415039,13.53911018371582,13.767926216125488,12.224029541015625,11.335084915161133,8.479722023010254,7.086574077606201,7.10796594619751,7.40675163269043,9.108685493469238,9.103070259094238,9.115341186523438,9.10976505279541,7.809466361999512,7.741933822631836,9.053292274475098,9.090476036071777,9.009339332580566,7.444098472595215,5.074955463409424,-6.751409530639648,-6.7788848876953125,-6.821265697479248,-6.834986209869385,-6.649367332458496,-6.986593723297119,-7.12266206741333,-7.128787994384766,-6.91353702545166,-6.6251068115234375,-6.715210437774658,-6.735212802886963,-6.63920259475708,-6.548386573791504,-6.688226699829102,-6.622648239135742,-7.1608147621154785,-7.19101095199585,-7.07489013671875,-7.0175652503967285,-6.9988322257995605,-7.053553104400635,-6.071959018707275,-6.342395782470703,-6.693566799163818,-6.244723320007324,-6.312698841094971,-4.796125888824463,-4.799439907073975,-4.792489528656006,-4.791006088256836,-4.832588195800781,-4.801961898803711,-4.774886131286621,-4.7762837409973145,-4.799835205078125,-4.534278869628906,-4.585070610046387,-4.8857269287109375,-4.805833339691162,-4.7863006591796875,-4.1553754806518555,-4.131508827209473,-4.140524864196777,-4.126410961151123,-4.10453987121582,-4.0948920249938965,-4.309577941894531,-4.301506996154785,-4.2000603675842285,-4.6947526931762695,-4.443816184997559,-7.224820613861084,-5.192275047302246,-5.192534923553467,11.386990547180176,11.48902702331543,11.648764610290527,11.748254776000977,11.848587989807129,11.626254081726074,11.28813362121582,11.093952178955078,12.104246139526367,11.993467330932617,12.718496322631836,12.658955574035645,12.947142601013184,13.482568740844727,-6.9435224533081055,-6.926896095275879,-6.922163486480713,-6.910543918609619,-6.930900573730469,-6.902542591094971,-7.04276704788208,-6.9210381507873535,-5.6603922843933105,-4.443896293640137,-4.407066345214844,-4.586562633514404,-4.532913684844971,-4.894661903381348,7.508488178253174,7.469905853271484,7.457393646240234,7.131023406982422,5.569406509399414,2.7264199256896973,1.9437602758407593,0.6384197473526001,0.47266775369644165,-0.6558046340942383,-1.840474009513855,-1.7923957109451294,-1.8410879373550415,-2.268528461456299,-0.47975045442581177,-0.2832854986190796,-0.20959584414958954,2.6271278858184814,2.866058826446533,2.8223230838775635,2.878410816192627,2.4300954341888428,1.4535467624664307,1.4225080013275146,1.4895026683807373,2.0072619915008545,3.047020435333252,3.709458112716675,-5.458817005157471,-5.442961692810059,-5.467497825622559,-5.467505931854248,-5.441255569458008,-5.449864864349365,-5.449129104614258,-5.442960739135742,-5.41913366317749,-5.449305534362793,-5.4491705894470215,-5.440067291259766,-5.430154800415039,-5.463050842285156,12.005935668945313,12.049245834350586,11.474831581115723,9.805758476257324,9.717663764953613,9.653470993041992,10.327485084533691,15.548990249633789,15.621024131774902,15.046134948730469,15.195170402526855,15.172204971313477,13.621582984924316,9.60519790649414,1.2824407815933228,0.624713659286499,0.8082004189491272,0.9640845060348511,3.291475296020508,4.594642639160156,4.677484512329102,3.0007526874542236,5.559235095977783,6.145500183105469,5.889662742614746,5.962202548980713,6.211541652679443,6.0948357582092285,-0.48138707876205444,-0.3537321984767914,-0.38488930463790894,-0.21359393000602722,-0.22709301114082336,-0.28242605924606323,-0.3363279402256012,-0.39067792892456055,-0.9380667209625244,-1.8971524238586426,-1.8824471235275269,-1.9046107530593872,-2.288404703140259,-2.6256752014160156,-0.6162705421447754,1.4219852685928345,1.9043734073638916,2.3454818725585938,2.5607235431671143,3.213150978088379,3.15928053855896,3.093294620513916,3.0442254543304443,2.030794858932495,2.046053886413574,0.45181772112846375,0.9079436659812927,1.0298576354980469,2.6144859790802,3.0129101276397705,2.995598793029785,3.0228936672210693,3.044801950454712,2.9606997966766357,2.0141780376434326,1.5446372032165527,0.7344115972518921,-0.21239204704761505,-0.7758494019508362,-0.7220721244812012,-0.8372551202774048,-0.8095608353614807,0.8351679444313049,0.9658697247505188,0.972430408000946,0.8911287784576416,0.8078380227088928,0.5877788662910461,-0.6325343251228333,-0.728070080280304,-0.8756899237632751,-0.9254595041275024,-0.9111121892929077,-0.9802335500717163,-0.7435186505317688,-0.39572182297706604,13.714364051818848,13.693805694580078,13.647815704345703,13.62614917755127,13.59709644317627,13.608346939086914,14.243172645568848,14.306344032287598,14.383922576904297,14.239399909973145,13.923433303833008,13.770844459533691,14.205727577209473,14.223495483398438,-0.9260590672492981,-0.37587836384773254,0.7592591047286987,-0.6924839019775391,-6.306826591491699,-6.226284027099609,-6.170064449310303,-5.81138801574707,-5.97531270980835,-5.421065330505371,-5.4525837898254395,-5.415065765380859,-5.4018168449401855,-3.0547611713409424,-2.4159090518951416,-2.427441358566284,-2.4170501232147217,-2.486576795578003,-2.5229127407073975,-2.5163931846618652,-2.870357036590576,-2.933523416519165,-2.9096720218658447,-2.9884450435638428,-3.0315864086151123,-3.2166059017181396,-3.1376209259033203,-3.124786615371704,-1.9101697206497192,-1.966863989830017,-2.079638957977295,-4.045973777770996,-4.09499454498291,-4.143043041229248,-4.256715774536133,-4.783430576324463,-5.696547508239746,-5.768374919891357,-5.752540588378906,-5.723199844360352,-5.826422691345215,-5.738162994384766,6.6437482833862305,5.463733673095703,5.418209075927734,5.450539588928223,5.465543746948242,7.266409873962402,9.365900993347168,9.54491138458252,5.627103328704834,-0.1508416086435318,-1.8787586688995361,-1.9789111614227295,-0.8868604898452759,0.17065872251987457,5.506093502044678,5.551028251647949,5.42665958404541,4.208735942840576,4.150761604309082,4.186639308929443,3.947354555130005,4.111317157745361,4.277615070343018,5.593654632568359,5.500823497772217,4.078336238861084,2.9122819900512695,2.2297449111938477,2.167306661605835,2.4235892295837402,2.488593816757202,3.6652793884277344,3.3098409175872803,-2.026064395904541,6.945089817047119,7.068628311157227,6.135852813720703,5.882212162017822,5.870206356048584,4.521425247192383,-3.0361249446868896,-5.387678623199463,-4.456781387329102,-4.430797100067139,-4.437193870544434,-4.547296524047852,-4.499452114105225,-4.600032329559326,-4.852993965148926,-5.521879196166992,-5.94215726852417,-5.922520160675049,-5.898547649383545,-5.927239894866943,-5.9584197998046875,-5.9558563232421875,7.750126361846924,7.757030010223389,7.701667308807373,7.478654384613037,7.26202917098999,6.9963178634643555,6.536803722381592,6.164801120758057,5.303163051605225,5.2303667068481445,3.5313873291015625,2.9846739768981934,3.1028716564178467,2.2244813442230225,-0.8547751307487488,-0.8538616895675659,-0.8554449677467346,-0.8244030475616455,-0.8535414934158325,-0.6833416223526001,-0.8512900471687317,-1.5651566982269287,-1.8055028915405273,-2.112022876739502,-2.4607343673706055,-2.151853084564209,-2.44205641746521,-2.611706495285034,2.0515215396881104,2.0798473358154297,-2.840547800064087,-3.39754319190979,4.573611259460449,5.686271667480469,5.959250450134277,7.6140007972717285,6.432252407073975,5.360023498535156,5.309700965881348,5.469099044799805,6.299346923828125,7.326760768890381,-1.9358447790145874,-1.990433931350708,-3.090038299560547,-4.223048210144043,-4.290935516357422,-4.37899923324585,-4.488364219665527,-4.729593276977539,-5.94758939743042,-6.001585960388184,-6.062267303466797,-6.234490871429443,-6.59567403793335,-6.662440776824951,-3.1093482971191406,3.3936851024627686,6.4575018882751465,6.658195495605469,6.6221232414245605,6.467021942138672,3.961463451385498,2.7087173461914063,1.861079454421997,2.175372838973999,2.7480528354644775,1.7744311094284058,1.34521484375,-1.6503955125808716,1.4321733713150024,1.3967041969299316,1.3552327156066895,0.6206684708595276,0.526630163192749,-0.08415824174880981,-1.7989543676376343,-2.459733724594116,-2.331745147705078,-2.3577888011932373,-2.4684274196624756,-0.8660619258880615,2.745669364929199,2.815830707550049,-3.1463210582733154,-3.1653313636779785,-3.171565294265747,-2.9596431255340576,-2.9360437393188477,-2.938788652420044,-2.960007667541504,-2.9110360145568848,-2.8956174850463867,-2.955435037612915,-3.0628111362457275,-3.0196423530578613,-3.1110267639160156,-3.2622320652008057,-4.634574890136719,-4.106042385101318,-4.079640865325928,-4.070524215698242,-3.007178544998169,-3.0311598777770996,-2.959343910217285,-3.1409196853637695,-3.1419169902801514,-3.302631378173828,-4.193191051483154,-4.545343399047852,-5.300274848937988,-5.759114742279053,-0.6161637902259827,-0.8117538094520569,0.32430580258369446,0.13441315293312073,0.2181473821401596,0.33865854144096375,2.140855550765991,2.373908758163452,2.3308165073394775,2.020764112472534,1.3833874464035034,-0.6247729659080505,-0.5385733246803284,-0.548366904258728,-2.879882574081421,-2.9332056045532227,-2.9074857234954834,-3.5036425590515137,-3.5143988132476807,-3.470869541168213,-3.4739065170288086,-4.053164005279541,-3.0315868854522705,-2.1717069149017334,-2.252675771713257,-2.2789387702941895,-2.2274649143218994,-2.9407882690429688,14.652375221252441,13.820837020874023,13.752041816711426,13.916813850402832,13.80465316772461,13.847030639648438,14.853413581848145,15.027534484863281,14.858235359191895,15.146614074707031,14.799080848693848,14.831682205200195,14.720755577087402,14.688694953918457,17.128969192504883,17.104299545288086,17.123458862304688,15.829992294311523,15.654186248779297,16.087827682495117,16.21817398071289,16.512346267700195,15.768613815307617,14.788833618164063,15.10094165802002,14.84007740020752,15.362327575683594,15.32479476928711,9.800708770751953,9.730498313903809,9.621488571166992,9.617929458618164,9.59720516204834,8.33464241027832,8.18058967590332,7.609228134155273,7.82695198059082,7.200061321258545,4.299679756164551,5.4022216796875,3.938098192214966,2.2433364391326904,-4.028358459472656,-4.236555576324463,-4.22998571395874,-4.342128276824951,-4.43910551071167,-5.627548694610596,-5.847489833831787,-5.859774112701416,-5.822126865386963,-5.7700724601745605,-6.704057693481445,-6.9091362953186035,-7.160892486572266,-7.302440166473389,11.548284530639648,11.716790199279785,11.719805717468262,11.793291091918945,11.811910629272461,11.807747840881348,11.782110214233398,11.759439468383789,11.662168502807617,11.779797554016113,11.859192848205566,11.417511940002441,10.86326789855957,10.737876892089844,-4.446282386779785,-4.719719886779785,-4.712065696716309,-5.655393123626709,-5.442418575286865,-5.163461208343506,-2.987851619720459,-3.1037566661834717,-2.9817235469818115,-4.084802627563477,-4.2237958908081055,-4.764487266540527,-5.054502964019775,-5.7769670486450195,16.27652931213379,16.28376007080078,16.303279876708984,16.335857391357422,16.33685302734375,16.353805541992188,16.31696319580078,16.357654571533203,15.648122787475586,14.484198570251465,14.593160629272461,15.001984596252441,14.930901527404785,14.929198265075684,16.320629119873047,16.3167724609375,16.33342933654785,16.358558654785156,16.359088897705078,16.421754837036133,16.5223445892334,16.683870315551758,16.446340560913086,16.76026725769043,16.792360305786133,16.83881378173828,15.75235366821289,15.926911354064941,4.625546455383301,4.696286201477051,5.042379379272461,4.8680949211120605,4.575431823730469,4.58972692489624,4.433095455169678,5.763927936553955,6.193761348724365,6.7968573570251465,5.940484046936035,6.027853012084961,7.07584285736084,7.135141849517822,3.238375186920166,3.2105839252471924,3.2666633129119873,1.7599431276321411,1.691613793373108,1.7101508378982544,1.7437688112258911,2.7623207569122314,6.694736957550049,6.058873176574707,6.362067699432373,6.142724990844727,7.157989025115967,6.914550304412842,16.18765640258789,16.193782806396484,16.301538467407227,16.362735748291016,16.323278427124023,16.41158103942871,16.47020721435547,16.348302841186523,15.853621482849121,15.700860977172852,15.605766296386719,15.545105934143066,15.900943756103516,15.902236938476563,17.019319534301758,16.955425262451172,17.026296615600586,16.99954605102539,16.917695999145508,16.97913932800293,16.920513153076172,16.811195373535156,16.670551300048828,16.644495010375977,16.570232391357422,15.856307029724121,15.629242897033691,15.801502227783203,3.466428279876709,3.3900504112243652,3.1591196060180664,3.397784948348999,3.352097988128662,4.001784324645996,4.720113754272461,4.603138446807861,3.777329683303833,3.9054200649261475,3.642404794692993,2.254457950592041,0.44310909509658813,0.24549497663974762,-6.839475154876709,-6.829592227935791,-6.790189266204834,-6.748330116271973,-6.784112930297852,-6.771598815917969,-6.76674747467041,-6.758944034576416,-6.75977087020874,-6.76983118057251,-6.839108467102051,-7.0402302742004395,-7.057960510253906,-7.099977493286133,-1.3101311922073364,-1.3394346237182617,-1.3583935499191284,-1.382982850074768,-1.8111324310302734,-1.9939746856689453,-1.9823501110076904,-2.241673469543457,-1.9199758768081665,-1.9883942604064941,-2.624199151992798,-2.854660749435425,-2.907053232192993,-2.918945074081421,16.47472381591797,16.43157196044922,16.430997848510742,16.468727111816406,16.48066520690918,16.480085372924805,16.422271728515625,16.46405601501465,16.489503860473633,16.442506790161133,16.45738410949707,16.649843215942383,16.430065155029297,16.566669464111328,14.615745544433594,14.774811744689941,14.924714088439941,14.789173126220703,14.780649185180664,14.793001174926758,14.93505573272705,14.890893936157227,14.818148612976074,14.769414901733398,14.741532325744629,14.72741413116455,14.61817455291748,14.450881958007813,-3.1157984733581543,-3.118833541870117,-3.0948050022125244,-3.075697898864746,-3.060554027557373,-3.070725917816162,-3.1181271076202393,-3.054642915725708,-3.0379652976989746,-3.044832229614258,-3.0356485843658447,-3.025324821472168,-3.0273542404174805,-3.0174143314361572,13.695528984069824,14.264871597290039,14.284138679504395,14.467801094055176,14.476716041564941,14.538996696472168,14.482909202575684,14.325614929199219,14.380680084228516,14.367019653320313,14.249859809875488,14.399261474609375,14.273297309875488,14.861529350280762,3.392686128616333,3.5279541015625,3.9656355381011963,5.348464488983154,5.381743907928467,4.143405437469482,3.5036509037017822,1.131385087966919,3.984265089035034,5.5705084800720215,5.799807548522949,5.677759647369385,5.989133358001709,5.78471040725708,4.99817419052124,5.1254658699035645,4.900172233581543,4.457780838012695,4.395369052886963,4.338586807250977,4.417830944061279,4.556318283081055,4.175361633300781,4.021118640899658,4.307923793792725,4.237314224243164,4.246009349822998,4.354557514190674,0.8001479506492615,0.7991122603416443,1.007654070854187,2.102078676223755,2.6699891090393066,2.459787368774414,2.472074270248413,2.7931694984436035,2.283174514770508,0.9246638417243958,3.2184746265411377,5.789503574371338,5.531041622161865,4.202406883239746,3.2870616912841797,3.9443132877349854,2.119568347930908,-0.7473810911178589,-1.9553207159042358,-2.633776903152466,-2.963754415512085,-3.1068572998046875,-2.4616358280181885,3.1972591876983643,3.286123514175415,3.2285284996032715,3.471020460128784,4.2379326820373535,7.3048906326293945,7.445725440979004,7.46901273727417,7.436720848083496,7.414172649383545,6.113635540008545,5.982210159301758,5.930799961090088,5.781087875366211,5.793785572052002,4.990606784820557,4.519558429718018,2.3682737350463867,0.7887859344482422,-3.0240306854248047,-3.011547088623047,-3.0325279235839844,-3.031865119934082,-3.0095794200897217,-3.05489444732666,-3.0207135677337646,-3.0059702396392822,-2.9772915840148926,-2.9695441722869873,-2.9781875610351563,-2.9520328044891357,-2.9721665382385254,-2.9532196521759033,16.262462615966797,16.275089263916016,16.282983779907227,16.29523277282715,16.308473587036133,16.330171585083008,16.621641159057617,16.64167594909668,16.652118682861328,15.80339527130127,15.676681518554688,15.686498641967773,15.54453182220459,15.511529922485352,9.07429027557373,9.073992729187012,9.060506820678711,9.104926109313965,9.057848930358887,9.090709686279297,9.071025848388672,8.997152328491211,8.866376876831055,8.838919639587402,8.921637535095215,8.929298400878906,8.949859619140625,9.025962829589844,0.044573355466127396,-7.181231630966067E-4,-0.34595900774002075,-0.46218281984329224,-0.46251240372657776,-0.4979841113090515,-0.4493834674358368,-0.5062144994735718,-0.41027212142944336,-0.37936535477638245,-0.32329505681991577,-0.29512327909469604,0.1132996454834938,0.42337557673454285,-6.295828819274902,-6.333985328674316,-6.3031415939331055,-6.297483921051025,-6.307969570159912,-6.307408332824707,-6.298927307128906,-6.299517631530762,-6.296056270599365,-6.285250663757324,-6.295053482055664,-6.3920698165893555,-6.397214412689209,-6.330944061279297,1.3213306665420532,1.3211922645568848,1.2140110731124878,1.268096685409546,1.285782814025879,1.2514232397079468,1.2574926614761353,1.2789632081985474,2.441159963607788,2.571134328842163,3.004521608352661,2.953355073928833,3.1121773719787598,1.173940896987915,16.34886932373047,16.31001091003418,15.372897148132324,15.226906776428223,15.23035717010498,14.84091567993164,14.843985557556152,14.656405448913574,15.00174331665039,15.70190143585205,15.412079811096191,14.887359619140625,15.291020393371582,14.560585975646973,-6.924360752105713,-6.8538713455200195,-6.864923477172852,-6.8218183517456055,-6.82616662979126,-6.81644344329834,-6.826902389526367,-6.819690704345703,-6.754030227661133,-6.779026508331299,-6.7868499755859375,-6.824506759643555,-6.818435192108154,-6.9183478355407715,-5.561606407165527,-2.565886974334717,10.73076057434082,10.541434288024902,9.85782241821289,9.555816650390625,9.549154281616211,9.605375289916992,11.022211074829102,10.52829360961914,9.822009086608887,2.8478267192840576,-3.0557925701141357,-0.15189693868160248,2.268021821975708,2.1289634704589844,1.9081329107284546,-0.06911739706993103,-1.0723774433135986,-1.886555552482605,-4.070655822753906,-4.357802867889404,-4.399421691894531,-4.420742034912109,-4.477629661560059,-4.629483699798584,-4.629632472991943,-4.661128520965576,-0.32030951976776123,-0.520598292350769,-0.5407367944717407,-0.6818556785583496,-1.5696766376495361,-1.234365463256836,-1.156102180480957,-1.2315806150436401,-1.2695257663726807,1.232862949371338,1.7656233310699463,1.3845906257629395,-1.376278281211853,-1.2270054817199707,15.685151100158691,15.34716796875,15.362807273864746,15.35811710357666,15.298681259155273,15.093208312988281,15.097354888916016,15.349663734436035,15.440692901611328,15.132329940795898,15.289133071899414,15.101411819458008,14.765719413757324,14.891934394836426,15.577034950256348,15.61925220489502,15.617870330810547,15.625370979309082,15.59974193572998,15.766396522521973,15.739273071289063,15.835535049438477,15.84542179107666,15.886826515197754,15.137053489685059,14.801162719726563,14.410490989685059,14.602431297302246,-4.922605037689209,-4.8998284339904785,-4.918153762817383,-5.1018195152282715,-5.224457263946533,-5.199224472045898,-5.4195556640625,-5.454574108123779,-5.366294860839844,-5.602399826049805,-5.555780410766602,-5.632715225219727,-5.827250003814697,-5.801605224609375,-7.09180212020874,-5.602268218994141,-5.647583961486816,-5.677510738372803,-5.671522617340088,-5.7017598152160645,-5.677985668182373,-5.607812404632568,-5.1787590980529785,-5.197068214416504,-5.2564873695373535,-5.310729026794434,-5.243073463439941,-5.240219593048096,-3.810025215148926,-3.750572919845581,-3.4103171825408936,-3.521043539047241,-3.0628879070281982,-3.4994008541107178,-2.8495049476623535,-2.046522378921509,2.4415438175201416,12.408997535705566,11.60604190826416,8.841814994812012,5.58131217956543,4.185872554779053,-7.272130966186523,-7.256216049194336,-7.283204078674316,-7.277093887329102,-7.41050386428833,-7.445977687835693,-7.362750053405762,-7.281678676605225,-7.461706161499023,-7.445953369140625,-7.439730167388916,-7.455252170562744,-7.52992057800293,-7.54034423828125,-6.96328067779541,-7.076792240142822,-7.028581142425537,-7.006984233856201,-7.02742862701416,-6.925530910491943,-6.8874831199646,-6.847285270690918,-6.881624221801758,-6.859543323516846,-7.171024322509766,-7.336215972900391,-7.314257621765137,-7.142339706420898,-4.43245792388916,-4.434919834136963,-4.418484687805176,-4.464852809906006,-4.381447792053223,-4.421697616577148,-5.457435607910156,-5.571069240570068,-5.593021869659424,-5.661349296569824,-5.651584148406982,-5.595095634460449,-5.517125606536865,-5.595719337463379,-5.766232013702393,-5.799163341522217,-5.820582389831543,-5.85766077041626,-5.905831336975098,-5.895749092102051,-5.874391078948975,-5.971033096313477,-5.971630096435547,-5.91801118850708,-5.898632526397705,-6.299788475036621,-6.4416632652282715,-6.181875705718994,-6.059464931488037,-6.050811767578125,-6.076550006866455,-6.015167236328125,-6.015058994293213,-5.97169303894043,-6.003398895263672,-5.977487564086914,-5.970712661743164,-5.975869655609131,-5.908876419067383,-5.958544731140137,-5.978964805603027,-5.898458957672119,-3.113085985183716,-3.1777803897857666,-3.9330666065216064,-4.0241827964782715,-4.016241073608398,-4.127593517303467,-4.101734161376953,-4.121183395385742,-4.108409881591797,-3.393793821334839,-3.334649085998535,-3.8971173763275146,-4.324361324310303,-4.493598461151123,-5.956172943115234,-5.993904113769531,-6.037481784820557,-6.030324935913086,-6.029024124145508,-5.960264205932617,-5.9569501876831055,-4.684117317199707,-4.589112758636475,-4.655208587646484,-4.547116756439209,-4.579833507537842,-4.578209400177002,-4.534550189971924,-5.511172771453857,-5.48854398727417,-5.492707252502441,-5.495833396911621,-5.5072832107543945,-5.518153667449951,-5.474578857421875,-5.492776393890381,-5.4628496170043945,-5.454253196716309,-5.498359203338623,-5.463840484619141,-5.332530498504639,-5.304107189178467,3.342434883117676,3.2942471504211426,3.1948659420013428,3.046184778213501,3.058715343475342,2.348724603652954,1.7326892614364624,1.5721598863601685,1.695417046546936,1.765252709388733,5.266971588134766,6.813348770141602,6.68244743347168,6.279771327972412,-5.083621978759766,-5.0966057777404785,-5.070758819580078,-5.110256671905518,-5.098424434661865,-5.086122035980225,-5.060760974884033,-5.052753448486328,-5.066493988037109,-5.096843242645264,-5.052703857421875,-5.101985931396484,-5.097262859344482,-5.10538911819458,-2.1228623390197754,-2.1051549911499023,-2.0462231636047363,-1.9712032079696655,-2.011532783508301,-1.967368721961975,-1.9343968629837036,-1.5555732250213623,-1.877328872680664,-2.0138697624206543,-2.0530033111572266,-2.149576187133789,-2.2851622104644775,-3.1918134689331055,-5.4616241455078125,-5.410330772399902,-5.364932537078857,-5.503681182861328,-5.4850311279296875,-5.5009965896606445,-5.399560451507568,1.0843449831008911,2.592538356781006,2.0183894634246826,1.2852864265441895,1.528051733970642,5.781698226928711,6.335911273956299,1.1721422672271729,1.1481359004974365,1.544508457183838,5.28045654296875,7.076931476593018,7.2050981521606445,7.494800567626953,7.394078731536865,7.376894474029541,5.99080753326416,5.69566535949707,5.613856315612793,5.645923137664795,4.567099571228027,-2.709869623184204,-2.7683022022247314,-4.5981059074401855,-3.2882754802703857,-2.759645462036133,-0.40117499232292175,-0.3726106584072113,-0.38393402099609375,-0.30921563506126404,-0.16517387330532074,-0.12828437983989716,-0.04756391420960426,-4.0316643714904785,-2.9809372425079346,11.883251190185547,11.854666709899902,12.277624130249023,12.922368049621582,12.899409294128418,12.879814147949219,13.022061347961426,13.266098022460938,13.173075675964355,13.321391105651855,13.258695602416992,13.0923433303833,13.019046783447266,12.472752571105957,-7.080191135406494,-7.105730056762695,-7.122674942016602,-7.107889175415039,-7.107995510101318,-7.151854038238525,-7.076130390167236,-7.17848014831543,-7.100704669952393,-7.125097274780273,-7.085448741912842,-6.948914527893066,-5.667453765869141,-5.520633220672607,-2.2434685230255127,0.07158768177032471,0.09315264970064163,-0.6283907294273376,-0.7108458876609802,-0.6247147917747498,-0.668362021446228,-0.6973053812980652,-0.2937034070491791,-0.6796947717666626,-2.448512554168701,-2.071896553039551,-2.8241357803344727,-3.636837959289551,-5.737951278686523,-5.759706974029541,-5.737894058227539,-5.719374656677246,-5.728668212890625,-5.701679706573486,-5.74005651473999,-5.741023540496826,-5.6614532470703125,-5.729050636291504,-5.691873073577881,-5.565729141235352,-5.548499584197998,-5.59725284576416,-5.989009380340576,-6.581103324890137,-2.7815566062927246,1.2225651741027832,-3.8400604724884033,-3.8003578186035156,-3.814970016479492,-4.01098108291626,-4.265164375305176,-4.3822197914123535,-4.371871471405029,-5.170459747314453,-5.385867595672607,-5.493300437927246,-5.535488605499268,-5.435098171234131,-5.426152229309082,-4.499596118927002,-0.8021751642227173,-0.37170153856277466,-0.3411831259727478,-0.3551271855831146,-0.03336016833782196,-0.31313228607177734,-0.29551374912261963,-0.3445737659931183,-0.32729217410087585,-0.5715563893318176,5.604218006134033,7.762380123138428,7.5820465087890625,6.388225555419922,6.039555072784424,3.9281105995178223,2.5244650840759277,1.3695217370986938,1.2262552976608276,3.9051921367645264,7.109857559204102,11.961758613586426,12.145325660705566,10.43014144897461,6.471613883972168,6.5315842628479,6.562524318695068,7.11399507522583,7.269538402557373,9.3894681930542,9.195598602294922,9.001068115234375,7.6793532371521,6.009628772735596,5.993031024932861,5.829283237457275,5.918393611907959,5.680337905883789,-4.277316570281982,-4.282223701477051,-4.243992805480957,-3.9403798580169678,-3.87913179397583,-3.956042766571045,-3.9566030502319336,-3.8692710399627686,-3.6897225379943848,-3.2329511642456055,-4.082858085632324,-4.292758941650391,-4.393560409545898,-4.481396675109863,-4.534363746643066,-4.537452697753906,-4.508998394012451,-4.5180277824401855,-4.5389604568481445,-4.497368812561035,-4.500394344329834,-4.552502632141113,-4.562193870544434,-4.560674667358398,-4.66213846206665,-4.989891052246094,-4.997277736663818,-5.502644062042236,-6.677066326141357,-6.768733978271484,-6.431687355041504,-6.366975784301758,-6.374627590179443,-6.3856353759765625,-6.335728645324707,-6.368443012237549,-6.266346454620361,-6.2429375648498535,-6.2710089683532715,-6.29880952835083,-6.2834625244140625,-6.399940013885498,-2.51340913772583,-2.5437772274017334,-2.516727924346924,-1.9176645278930664,-1.9525821208953857,2.9030067920684814,4.414295673370361,4.043699741363525,5.365192890167236,3.119954824447632,2.571645975112915,3.118128776550293,4.190366268157959,3.5701100826263428,-5.600010871887207,-5.595300197601318,-5.581718921661377,-5.611774444580078,-5.577939033508301,-5.533185958862305,-5.561646938323975,-5.5374226570129395,-5.587137222290039,-5.562437534332275,-5.630167484283447,-5.653738498687744,-6.066813945770264,-6.09709358215332,-7.217018127441406,-7.211260795593262,-7.264455795288086,-7.4601335525512695,-7.502046585083008,-7.551875114440918,-7.4021830558776855,-7.293972969055176,-7.272460460662842,-7.264604568481445,-7.3047661781311035,-7.364774703979492,-7.254388809204102,-7.255345821380615,-2.9363667964935303,-2.879856586456299,-2.9348533153533936,-2.8925418853759766,-2.791407823562622,-2.743584632873535,-2.7562448978424072,-2.867746591567993,-2.783902406692505,-2.072981119155884,-0.7073906064033508,-1.4144729375839233,-1.3493155241012573,-2.0745396614074707,11.325151443481445,11.429776191711426,11.476507186889648,10.703923225402832,10.694746017456055,11.250630378723145,11.155244827270508,10.80269718170166,10.693583488464355,10.779019355773926,10.887813568115234,11.203627586364746,10.936837196350098,10.8832368850708,-7.005163669586182,-7.055912971496582,-7.041262149810791,-7.099851608276367,-7.098606586456299,-7.042234897613525,-7.06607723236084,-7.083260536193848,-7.092460632324219,-7.1149115562438965,-7.092932224273682,-7.128981590270996,-7.139346599578857,-7.128115653991699,-5.592894077301025,-5.6146135330200195,-5.581725120544434,-5.806027412414551,-5.804305553436279,-5.861570835113525,-5.86358118057251,-5.8547682762146,-6.200739860534668,-5.809031009674072,-5.977133274078369,-5.8783745765686035,-5.855031967163086,-5.82627534866333,-1.2630078792572021,-0.7040919661521912,-0.7234811186790466,-1.948935627937317,-1.9417870044708252,-1.9894706010818481,-1.9815967082977295,-1.8835471868515015,-2.2346253395080566,-2.230541467666626,-2.185133934020996,-1.9892135858535767,-1.985548973083496,-2.0311481952667236,-7.25254487991333,-7.245784282684326,-7.234179973602295,-7.307399749755859,-7.252824783325195,-7.290252685546875,-7.284979820251465,-7.533310890197754,-7.447725296020508,-7.379887104034424,-7.315860748291016,-7.353147029876709,-7.330390930175781,-7.261744499206543,15.492387771606445,15.589459419250488,15.603940963745117,15.291229248046875,15.31907844543457,15.238906860351563,14.99895191192627,15.045145034790039,14.91402530670166,15.157739639282227,15.12663459777832,15.000604629516602,14.488689422607422,14.860584259033203,-6.8498053550720215,-7.214344024658203,-7.304720401763916,-7.270676612854004,-7.226180553436279,-6.936307907104492,-6.8770952224731445,-6.874814987182617,-6.789153575897217,-6.798323154449463,-6.777393817901611,-6.81160831451416,-6.784482002258301,-6.764124870300293,9.746167182922363,9.742015838623047,9.737469673156738,9.740743637084961,9.730884552001953,9.772273063659668,9.735211372375488,9.74361515045166,9.740933418273926,9.749007225036621,9.739058494567871,9.719847679138184,9.742835998535156,9.772581100463867,16.645116806030273,16.682775497436523,16.610580444335938,16.746559143066406,16.786203384399414,16.779420852661133,16.740814208984375,16.73118782043457,16.721553802490234,16.7189884185791,16.46881103515625,16.514204025268555,16.59185028076172,16.34086799621582,2.7876062393188477,2.8224027156829834,2.782576560974121,2.4042251110076904,2.3853888511657715,2.0744216442108154,2.113353967666626,1.9523526430130005,1.0247620344161987,1.1200999021530151,1.1639736890792847,1.0340584516525269,1.1006375551223755,1.0418941974639893,7.955048561096191,7.882603645324707,7.786198616027832,7.691445827484131,7.918075084686279,7.85409688949585,7.892189979553223,6.939318656921387,6.670599937438965,6.6003193855285645,6.545050144195557,7.855440139770508,9.837837219238281,7.813908100128174,-0.7106184959411621,-0.19118450582027435,-0.2221246063709259,1.1864978075027466,1.181209683418274,-1.236258625984192,-1.4337222576141357,-2.028449535369873,-2.8224072456359863,-4.048542022705078,-4.30195951461792,-4.2729058265686035,-4.3121819496154785,-4.379510879516602,14.210232734680176,14.376286506652832,14.552714347839355,13.87511157989502,13.918407440185547,13.673815727233887,12.197859764099121,11.33250617980957,11.379003524780273,11.410472869873047,12.170927047729492,11.69972038269043,11.147834777832031,10.973666191101074,-6.90863561630249,-6.853431224822998,-6.848241806030273,-6.904582977294922,-6.917240142822266,-6.890889644622803,-6.9264750480651855,-6.9033122062683105,-6.83950662612915,-6.777373790740967,-6.788279056549072,-6.7403740882873535,-6.751991271972656,-6.771355152130127,14.303831100463867,14.323982238769531,14.250731468200684,14.352773666381836,14.298194885253906,14.341998100280762,14.263070106506348,14.018662452697754,13.90278148651123,13.858393669128418,12.994003295898438,12.117660522460938,11.613726615905762,11.430743217468262,16.03384780883789,16.216495513916016,16.22109031677246,15.529534339904785,15.091726303100586,15.092705726623535,15.015793800354004,14.10808277130127,13.477143287658691,13.263875007629395,13.481810569763184,13.12382984161377,15.061688423156738,15.624263763427734,16.29664421081543,16.33772850036621,16.33383560180664,16.320770263671875,16.323362350463867,16.328927993774414,16.340778350830078,16.344818115234375,16.318805694580078,16.342147827148438,16.348922729492188,16.356569290161133,16.352190017700195,16.31875228881836,-7.5409255027771,-7.5276994705200195,-7.56511926651001,-7.5285258293151855,-7.54810905456543,-7.544110298156738,-7.58088493347168,-7.571993350982666,-7.586773872375488,-7.567590713500977,-7.545813083648682,-7.530206680297852,-7.536980152130127,-7.579123497009277,16.618303298950195,16.620901107788086,16.625946044921875,16.6278133392334,16.758499145507813,16.847246170043945,17.011001586914063,17.07947540283203,17.003787994384766,16.849773406982422,16.871578216552734,16.901256561279297,16.898693084716797,16.908334732055664,-6.128421783447266,-6.047964096069336,-6.184426784515381,-6.192798614501953,-5.453729629516602,-2.8461837768554688,-2.829359769821167,-2.8112621307373047,-2.813650608062744,-2.8840556144714355,-2.848848342895508,-2.7428081035614014,-2.672313690185547,0.7654862403869629,16.839698791503906,16.88066291809082,16.824827194213867,16.840557098388672,16.837379455566406,16.11118507385254,16.00310516357422,16.165420532226563,16.48798942565918,16.506031036376953,16.476451873779297,16.340166091918945,16.290176391601563,15.980204582214355,16.359739303588867,16.38475227355957,16.260364532470703,15.91849136352539,15.96949577331543,15.235692024230957,15.1730318069458,15.11756420135498,15.106832504272461,15.039315223693848,13.467042922973633,12.14004135131836,11.841151237487793,11.451942443847656,2.933922290802002,2.9124608039855957,3.0137369632720947,3.844291925430298,3.8423311710357666,5.50638484954834,5.786031723022461,5.834573268890381,5.779470920562744,5.223871231079102,2.999748945236206,1.6753265857696533,1.0668096542358398,0.9622408747673035,0.22506606578826904,0.19916915893554688,0.16956959664821625,0.0970592126250267,0.13846389949321747,0.019073177129030228,-0.03849191591143608,-0.08044350147247314,-0.10151918977499008,-0.09768673777580261,-3.1146068572998047,-6.72202205657959,-6.719998836517334,-6.739835739135742,15.312102317810059,15.312980651855469,15.280232429504395,15.03715991973877,15.063516616821289,15.046761512756348,15.08821964263916,15.023177146911621,15.284858703613281,14.976326942443848,15.04106330871582,14.327507019042969,14.16226577758789,14.368541717529297,11.16550064086914,11.222830772399902,11.1748628616333,10.989896774291992,11.015708923339844,10.970413208007813,10.760039329528809,10.05647087097168,9.668899536132813,9.799491882324219,10.57844352722168,11.066561698913574,10.853006362915039,10.418807983398438,-0.07513275742530823,-0.06153765320777893,-0.08293191343545914,-0.0935402661561966,-0.08139623701572418,-0.0844459980726242,-0.09202871471643448,-0.017030766233801842,-0.12327288836240768,-0.08763498812913895,-0.12276960164308548,-0.06460639834403992,-0.08325980603694916,-0.058479029685258865,15.18651294708252,15.045780181884766,14.987682342529297,14.793967247009277,14.695804595947266,14.874590873718262,14.469204902648926,14.23180103302002,14.295048713684082,14.392617225646973,14.267345428466797,14.068106651306152,14.088865280151367,14.022875785827637,15.305546760559082,15.31978988647461,15.299149513244629,15.317693710327148,15.328957557678223,15.280179977416992,15.298243522644043,15.296146392822266,15.404729843139648,15.288866996765137,15.385442733764648,15.337817192077637,15.52884292602539,15.573800086975098,2.1381454467773438,0.5108304619789124,0.046869371086359024,-0.5795443058013916,-0.5346894264221191,-0.6851149797439575,-0.6549125909805298,2.7291831970214844,3.5941081047058105,4.057947635650635,3.8974881172180176,3.6554157733917236,2.7004315853118896,2.7656450271606445,-2.685152053833008,-2.720991849899292,-2.7438313961029053,-2.759923219680786,-2.7200067043304443,-2.7310807704925537,-2.700336217880249,-2.740339756011963,-0.6629794836044312,0.20049895346164703,-0.8818013072013855,-0.8705983757972717,-0.5722249746322632,0.9917713403701782,12.696435928344727,12.75319766998291,12.694504737854004,12.063956260681152,11.838656425476074,11.993496894836426,11.963623046875,11.884998321533203,11.81760025024414,11.922507286071777,12.076912879943848,12.206352233886719,12.261006355285645,12.179665565490723,11.126158714294434,11.054347038269043,11.112056732177734,10.86605453491211,9.82715892791748,10.620654106140137,10.582193374633789,10.63564682006836,10.644304275512695,8.514782905578613,2.735206127166748,2.051597833633423,1.1779861450195313,0.4797000288963318,1.4344884157180786,1.4594542980194092,1.4364748001098633,0.650439441204071,0.5101607441902161,0.5019856691360474,0.44173571467399597,0.35484230518341064,0.4067511260509491,0.20408441126346588,0.574993371963501,1.3034166097640991,1.146994709968567,4.08504056930542,16.377208709716797,16.22948455810547,16.28902816772461,16.225479125976563,16.195297241210938,16.22301483154297,16.24981689453125,16.166614532470703,16.2310848236084,16.263988494873047,16.25984001159668,16.169801712036133,16.271638870239258,16.366491317749023,17.03046989440918,17.08671760559082,17.08260154724121,16.937654495239258,16.978574752807617,17.15076446533203,17.15432357788086,17.11334800720215,16.882896423339844,16.951284408569336,16.590002059936523,16.64495277404785,16.655210494995117,16.654998779296875,-6.387806415557861,-5.441899299621582,-5.3815436363220215,-5.375311851501465,-5.387930393218994,-5.381631851196289,-5.397312164306641,-5.379396915435791,-5.372855186462402,-5.382361888885498,-5.387820720672607,-5.372440338134766,-5.397214889526367,-5.389266490936279,6.084268093109131,6.203721046447754,5.327230453491211,3.5994434356689453,3.73956561088562,3.6980199813842773,3.675894021987915,3.6969411373138428,3.6904590129852295,3.7046666145324707,3.5598678588867188,3.680248260498047,3.6031861305236816,3.452465295791626,7.822585105895996,7.840791702270508,7.598005294799805,7.79664421081543,7.840277194976807,9.869409561157227,11.068071365356445,7.543023109436035,7.083162784576416,11.774250030517578,13.564323425292969,12.084206581115723,7.953431606292725,7.170504570007324,7.604660987854004,7.604252815246582,7.5590009689331055,7.613260269165039,7.655132293701172,7.977001667022705,7.647943019866943,7.484336853027344,7.4518938064575195,8.661359786987305,8.175554275512695,8.036758422851563,7.679512023925781,7.610385894775391,-6.397971153259277,-6.393438339233398,-6.4057135581970215,-6.398366451263428,-6.397834300994873,-6.408049583435059,-6.400485515594482,-6.4093780517578125,-6.407627105712891,-6.398159503936768,-6.406766414642334,-6.390134334564209,-6.399845600128174,-6.412456035614014,6.009859085083008,6.058432579040527,5.44620418548584,1.4508179426193237,0.05403735488653183,-0.49625444412231445,-0.7329825162887573,-1.9669368267059326,-2.1986019611358643,-2.0596330165863037,-2.395749568939209,-2.5584487915039063,-2.300114631652832,-2.2500805854797363,-0.2515195608139038,-0.22120527923107147,-0.2024921476840973,-0.187689870595932,-0.17206770181655884,0.033979158848524094,3.8341729640960693,4.0583953857421875,4.189499855041504,4.348438262939453,5.166041851043701,9.638047218322754,9.72360897064209,9.735845565795898,0.4533129334449768,0.4690154790878296,0.46841174364089966,0.49196377396583557,0.4557041823863983,0.47049012780189514,0.4679624140262604,0.4685806632041931,0.4859076142311096,0.4806297719478607,0.46605953574180603,0.44303765892982483,0.46996453404426575,0.4836716651916504,14.503473281860352,14.537921905517578,14.447500228881836,14.223957061767578,14.269462585449219,14.286689758300781,14.26911735534668,14.258790016174316,13.726738929748535,14.355182647705078,14.770100593566895,14.796575546264648,14.761173248291016,14.230645179748535,15.622842788696289,15.571026802062988,15.22735595703125,14.905545234680176,14.952967643737793,15.034392356872559,14.870084762573242,14.851083755493164,14.505188941955566,14.192310333251953,12.344497680664063,10.975430488586426,14.006967544555664,12.209793090820313,2.180156946182251,2.3637776374816895,2.3443450927734375,2.244103193283081,2.422696352005005,2.6370959281921387,3.1818957328796387,4.098013401031494,4.116353511810303,4.724406719207764,4.502399921417236,4.527684211730957,4.606696128845215,4.7371978759765625,9.254940032958984,9.259562492370605,9.297523498535156,9.358152389526367,9.374073028564453,9.413605690002441,10.907769203186035,11.200922966003418,11.039061546325684,10.740320205688477,10.485305786132813,11.127004623413086,11.28345012664795,11.795392990112305,-6.3509674072265625,-6.380373477935791,-6.388944149017334,-6.4066948890686035,-6.422035217285156,-6.40513801574707,-6.414900302886963,-6.405890941619873,-6.403614521026611,-6.413452625274658,-6.4052252769470215,-6.420276165008545,-6.41119909286499,-6.407619476318359,13.313429832458496,12.228861808776855,12.068121910095215,9.187992095947266,7.250197410583496,5.819094657897949,5.875199794769287,3.2058229446411133,0.774361789226532,0.5365593433380127,0.41994184255599976,0.22045451402664185,-0.002208397490903735,-0.6127400994300842,-2.6351852416992188,-2.496047258377075,-2.4778292179107666,-2.488173007965088,-2.503671884536743,-2.7819604873657227,-3.1397323608398438,-3.1363580226898193,-3.1126720905303955,-3.105477809906006,-3.106382369995117,-3.04353928565979,-3.051811456680298,-3.0687124729156494],\n",
       "\"second_dim\":[10.789642333984375,10.748023986816406,10.759872436523438,11.15598201751709,11.20717716217041,10.909117698669434,10.909132957458496,10.813725471496582,10.667604446411133,10.704126358032227,10.828063011169434,10.720906257629395,10.52577018737793,10.28216552734375,9.487627983093262,9.571357727050781,9.591426849365234,9.649613380432129,9.643869400024414,9.579833984375,9.501748085021973,9.612252235412598,9.7113676071167,10.140417098999023,9.64338493347168,9.589555740356445,9.383855819702148,9.62647533416748,3.661029577255249,3.7350378036499023,3.7640814781188965,3.7670416831970215,3.8264880180358887,3.845595359802246,3.8910534381866455,3.883917808532715,3.85105037689209,3.96327543258667,4.017668724060059,4.000807285308838,4.0518717765808105,5.341807842254639,2.825690269470215,2.817439317703247,2.8182291984558105,2.8325581550598145,2.8098597526550293,2.767068862915039,2.765801191329956,2.7722363471984863,2.79225754737854,2.75626540184021,2.829728126525879,2.828184127807617,2.8271076679229736,2.851503849029541,11.15017032623291,11.16502571105957,11.155240058898926,11.160242080688477,11.21459674835205,11.196130752563477,11.213653564453125,11.17612075805664,11.074142456054688,11.257862091064453,11.25221061706543,11.748631477355957,11.74303913116455,11.763608932495117,9.093003273010254,9.123135566711426,9.084691047668457,9.276885032653809,9.398276329040527,9.392365455627441,9.369935989379883,9.632847785949707,9.62120246887207,10.277687072753906,10.313701629638672,10.259112358093262,10.404664993286133,10.87678337097168,7.53681755065918,7.547610282897949,7.572784900665283,8.243523597717285,8.234644889831543,8.244081497192383,8.259836196899414,8.25574779510498,8.171775817871094,8.19660472869873,8.180811882019043,8.343485832214355,8.368107795715332,8.335014343261719,-0.7676922678947449,2.9495646953582764,4.724301338195801,6.168869495391846,6.326679706573486,6.505019664764404,7.646445274353027,7.732147216796875,7.651259899139404,8.389620780944824,8.399024963378906,-0.7449455261230469,-0.907966136932373,-1.1531010866165161,4.7978386878967285,4.694067478179932,4.250571250915527,4.095186233520508,3.5231552124023438,3.486445665359497,3.426293134689331,3.455704927444458,3.467139482498169,3.4577267169952393,3.7748098373413086,3.1698741912841797,2.052389621734619,1.938118815422058,11.8041410446167,11.843363761901855,11.900136947631836,11.758824348449707,11.791007041931152,11.774209976196289,11.771615982055664,11.81968879699707,11.745241165161133,11.64462661743164,11.853684425354004,11.805251121520996,11.70191764831543,11.36104965209961,1.198848009109497,1.0928188562393188,4.703529357910156,0.581142246723175,-0.5381431579589844,0.1309090554714203,0.47446611523628235,0.5027907490730286,0.5104321837425232,0.6518084406852722,0.638235867023468,0.6148655414581299,0.6611441969871521,0.781868577003479,4.728296279907227,5.304051399230957,5.697569847106934,5.3722124099731445,4.548336029052734,-0.07051658630371094,-1.2545949220657349,-1.2573727369308472,-1.2311675548553467,-1.23177969455719,-1.279012680053711,-1.2276694774627686,-1.2401164770126343,-1.1287182569503784,11.044285774230957,10.620528221130371,10.756537437438965,10.667439460754395,10.574251174926758,10.490653991699219,10.341185569763184,10.356478691101074,10.450834274291992,10.6756591796875,10.763182640075684,10.68272590637207,10.297844886779785,10.2398099899292,4.651918888092041,4.728057861328125,5.111776828765869,5.20376443862915,5.627472400665283,6.240471839904785,9.970300674438477,10.439146041870117,10.530107498168945,10.567928314208984,11.075088500976563,11.282279014587402,11.4177885055542,11.423130989074707,5.709496021270752,5.658502101898193,5.68013858795166,5.652719020843506,5.8178181648254395,6.203065395355225,8.967853546142578,9.235630989074707,9.644484519958496,10.68029499053955,10.45481014251709,10.788487434387207,10.578665733337402,8.48691463470459,4.185062408447266,4.288663864135742,4.254462242126465,4.15626859664917,4.197075366973877,4.145196914672852,4.645252227783203,7.18513298034668,7.365518569946289,7.469405174255371,7.610284805297852,7.278916835784912,7.1688408851623535,6.953066825866699,4.264011383056641,4.650886535644531,4.702348709106445,5.373309135437012,5.328793048858643,5.174494743347168,5.283128261566162,4.761386871337891,5.053957462310791,6.000387191772461,6.13992166519165,5.946084976196289,7.538427352905273,7.6623992919921875,11.059652328491211,11.005743980407715,10.981352806091309,11.031564712524414,10.723387718200684,10.722831726074219,10.68133544921875,10.710021018981934,10.790788650512695,11.325100898742676,10.260894775390625,6.698054313659668,6.401933193206787,6.38808012008667,6.785350799560547,6.6857476234436035,6.672747611999512,5.772097587585449,3.836787223815918,3.7307841777801514,3.771869659423828,3.689520835876465,3.426891565322876,3.3106441497802734,3.4328155517578125,3.3332505226135254,3.390672445297241,3.390674591064453,10.483494758605957,10.46855354309082,10.451436996459961,10.525636672973633,10.473133087158203,10.6478271484375,10.62778091430664,10.66447925567627,10.563243865966797,9.501385688781738,6.672061443328857,10.599434852600098,10.515158653259277,10.532120704650879,8.440438270568848,8.025318145751953,8.152384757995605,8.041690826416016,8.021469116210938,7.656795024871826,7.562890529632568,7.665075778961182,7.821439743041992,7.4817962646484375,6.20364236831665,5.619974613189697,1.2363141775131226,1.2640376091003418,8.09378433227539,8.393410682678223,8.266921043395996,8.41588020324707,9.133260726928711,8.498814582824707,8.69824504852295,8.273280143737793,7.119288921356201,7.223540782928467,7.3284101486206055,7.860651969909668,11.0325927734375,11.265242576599121,10.889281272888184,10.917880058288574,7.044924736022949,6.085252285003662,10.348698616027832,10.719352722167969,10.687544822692871,10.338233947753906,10.196916580200195,10.281185150146484,7.101842403411865,4.040102481842041,3.8208096027374268,3.634474754333496,9.398530960083008,9.414276123046875,9.405129432678223,9.46114444732666,9.453956604003906,9.042960166931152,8.491315841674805,8.3861722946167,7.936215400695801,7.2438764572143555,7.779000759124756,7.919822692871094,7.512545108795166,6.294743537902832,8.12099838256836,7.564101219177246,7.375219821929932,7.578864574432373,7.591059684753418,7.663997650146484,8.541016578674316,8.482638359069824,7.3203864097595215,7.589610576629639,7.335934638977051,8.710638999938965,9.092297554016113,10.24927043914795,11.02850341796875,10.930704116821289,10.880837440490723,10.401284217834473,10.434986114501953,10.410093307495117,10.291876792907715,10.480670928955078,10.453207015991211,10.134822845458984,10.065605163574219,10.183514595031738,10.579952239990234,11.118977546691895,1.0326564311981201,0.91609787940979,-0.11422982066869736,-0.32677870988845825,-0.1520087569952011,-0.6231330633163452,-0.7657695412635803,-0.8505997061729431,-0.4658379554748535,-0.12205008417367935,-1.330270528793335,-1.3531899452209473,-0.5209190249443054,1.6345535516738892,1.5153058767318726,1.5264790058135986,0.8746464848518372,0.8510168194770813,1.1765426397323608,1.2713861465454102,1.4245696067810059,1.3436919450759888,1.9016814231872559,-0.21393465995788574,-0.4100860059261322,-0.2127130776643753,-0.5295639634132385,1.8430261611938477,1.832453727722168,1.8361254930496216,1.8480223417282104,1.7890164852142334,1.8277766704559326,1.8440898656845093,1.81437087059021,1.8494328260421753,3.5030977725982666,3.463855028152466,1.9131851196289063,1.8396334648132324,1.8370238542556763,6.214961528778076,6.229874610900879,6.2399725914001465,6.2610673904418945,6.268540859222412,6.291922092437744,5.9868974685668945,6.017414093017578,5.9894700050354,5.623074531555176,5.814709186553955,-1.2641249895095825,-3.362424850463867,-3.3723487854003906,8.938583374023438,8.896475791931152,8.805106163024902,8.747336387634277,8.758438110351563,8.80735969543457,9.214739799499512,9.246331214904785,8.846181869506836,8.915797233581543,8.405487060546875,8.476470947265625,8.080057144165039,7.826009750366211,1.4133107662200928,1.4086918830871582,1.420050859451294,1.387627124786377,1.404713749885559,1.4253387451171875,1.3959181308746338,1.4005872011184692,4.402316570281982,5.422987461090088,5.4000468254089355,4.593977451324463,4.713677883148193,4.0587005615234375,10.517542839050293,10.594474792480469,10.568671226501465,10.824714660644531,11.336359977722168,11.771025657653809,11.509048461914063,10.840533256530762,10.730682373046875,9.98534107208252,8.374829292297363,8.640347480773926,8.316112518310547,7.762990474700928,10.345696449279785,10.389089584350586,10.417527198791504,11.387988090515137,11.41069507598877,11.418290138244629,11.42190170288086,11.398069381713867,11.260055541992188,11.281725883483887,11.312159538269043,11.595934867858887,11.587753295898438,11.746248245239258,-2.4614052772521973,-2.446779727935791,-2.474278211593628,-2.475013256072998,-2.4588780403137207,-2.4612622261047363,-2.4690332412719727,-2.4558138847351074,-2.4916374683380127,-2.4672272205352783,-2.474079132080078,-2.4612109661102295,-2.4539668560028076,-2.458235263824463,9.061933517456055,9.021222114562988,9.246780395507813,10.075278282165527,10.149681091308594,10.21586799621582,9.877169609069824,6.634537696838379,6.520054817199707,7.235840320587158,7.000782012939453,7.111576557159424,8.178393363952637,10.244766235351563,11.162943840026855,10.844136238098145,10.940624237060547,10.652021408081055,11.512622833251953,11.424088478088379,11.18197250366211,11.169758796691895,10.90787410736084,10.842805862426758,10.903556823730469,10.893020629882813,10.957138061523438,10.871574401855469,9.589447975158691,9.743279457092285,9.739465713500977,9.863083839416504,9.845416069030762,9.808490753173828,9.801629066467285,9.790670394897461,9.316596984863281,8.285362243652344,8.26462459564209,8.226678848266602,7.70888614654541,6.860970497131348,9.836949348449707,10.689399719238281,10.695490837097168,10.934371948242188,11.0664701461792,11.17348861694336,11.034619331359863,11.003576278686523,11.067520141601563,10.687868118286133,10.636094093322754,10.144662857055664,10.198187828063965,10.231856346130371,11.327875137329102,11.432787895202637,11.47233772277832,11.422548294067383,11.360626220703125,11.393082618713379,10.678176879882813,10.549432754516602,10.148313522338867,9.424968719482422,9.364113807678223,9.248665809631348,9.332618713378906,9.399055480957031,11.162637710571289,11.209105491638184,11.234461784362793,11.211048126220703,11.145875930786133,10.995036125183105,10.227846145629883,10.131128311157227,10.00160026550293,9.89720344543457,9.982452392578125,9.931185722351074,10.168755531311035,10.395498275756836,7.289741039276123,7.274002552032471,7.294373989105225,7.317066669464111,7.32917594909668,7.389541149139404,6.446559906005859,6.484529495239258,5.763247966766357,6.27573299407959,7.041774749755859,7.132565498352051,6.254256248474121,6.297744274139404,9.923506736755371,10.401000022888184,11.073439598083496,10.108564376831055,0.5109105110168457,0.40656113624572754,0.426259845495224,0.24753855168819427,0.5606118440628052,1.3024214506149292,1.2324697971343994,1.2613180875778198,1.306166648864746,4.333792209625244,6.39067268371582,6.366003036499023,6.338491439819336,6.201716899871826,6.132559299468994,6.088922500610352,5.435922622680664,5.3766326904296875,5.37922477722168,5.256768226623535,5.030541896820068,4.435429573059082,4.4079461097717285,4.372316837310791,7.348804473876953,7.357062816619873,7.141348361968994,5.074295520782471,5.011149883270264,4.937976837158203,4.785899639129639,3.474799633026123,2.3057918548583984,2.2378454208374023,2.2556777000427246,2.2992186546325684,2.154200315475464,2.241307020187378,11.077911376953125,11.346307754516602,11.281332969665527,11.303864479064941,11.315956115722656,10.784969329833984,10.135486602783203,10.144988059997559,11.244709968566895,10.309720039367676,8.27659797668457,8.10505199432373,9.51057243347168,10.04885482788086,11.48155689239502,11.443461418151855,11.500612258911133,11.887327194213867,11.897170066833496,11.899211883544922,11.902543067932129,11.892593383789063,11.924210548400879,11.465788841247559,11.47827434539795,11.917621612548828,11.865954399108887,11.832236289978027,10.780350685119629,10.861875534057617,10.799328804016113,11.336496353149414,11.629311561584473,8.256895065307617,10.879467964172363,10.820067405700684,10.871426582336426,10.912508010864258,10.895442962646484,11.570773124694824,4.656998157501221,1.3550301790237427,4.764254570007324,4.760167121887207,4.732112884521484,4.543765544891357,4.587847709655762,4.507871627807617,4.090294361114502,2.771256923675537,2.039393663406372,2.007455348968506,2.0114994049072266,1.9952312707901,1.9812883138656616,1.965535044670105,10.43692684173584,10.463955879211426,10.523564338684082,10.49499225616455,10.549553871154785,10.622979164123535,10.803186416625977,10.991573333740234,11.162467956542969,11.160401344299316,11.158891677856445,11.1594877243042,11.056421279907227,10.671117782592773,9.588181495666504,9.56185531616211,9.6056547164917,9.618120193481445,9.607515335083008,9.804947853088379,9.542618751525879,8.345990180969238,8.112252235412598,7.759379863739014,6.832441329956055,7.076511859893799,6.852392673492432,6.463728904724121,11.648177146911621,11.712322235107422,7.726161956787109,4.356263637542725,11.753215789794922,11.644054412841797,11.610030174255371,10.728385925292969,11.052526473999023,11.237471580505371,11.248159408569336,11.292462348937988,11.022095680236816,10.509146690368652,7.580073356628418,7.438449859619141,6.528529644012451,5.010180473327637,4.9863739013671875,4.9295501708984375,4.761959075927734,4.289127826690674,2.018712282180786,1.9816625118255615,1.9121551513671875,1.5772900581359863,-0.19579073786735535,-0.2913358509540558,5.117273330688477,10.895028114318848,10.786386489868164,10.698200225830078,10.730671882629395,10.784201622009277,11.666667938232422,11.693561553955078,11.53140926361084,11.322369575500488,11.209635734558105,11.331421852111816,11.165597915649414,8.422950744628906,11.414408683776855,11.438925743103027,11.438950538635254,10.898240089416504,10.843202590942383,10.482535362243652,8.540801048278809,6.209425926208496,6.662973880767822,6.518505096435547,6.229306221008301,9.706262588500977,11.548665046691895,11.427339553833008,4.957450866699219,4.894713401794434,4.848479747772217,5.341131687164307,5.396040916442871,5.408517837524414,5.354493618011475,5.438018321990967,5.476118087768555,5.379848957061768,5.217716693878174,5.247188091278076,5.134498596191406,5.051726818084717,3.5781326293945313,5.0162882804870605,5.037780284881592,5.047556400299072,6.575192451477051,6.608453750610352,6.575201511383057,6.436207294464111,6.471678733825684,6.276065349578857,4.891068458557129,3.888885259628296,2.2961254119873047,1.9797875881195068,9.633652687072754,9.57747745513916,10.1630220413208,10.051068305969238,10.086538314819336,10.179940223693848,10.621796607971191,10.625578880310059,10.637078285217285,10.460066795349121,10.112922668457031,9.006168365478516,9.087570190429688,9.08620548248291,7.7613325119018555,7.6746368408203125,7.710951805114746,6.659912586212158,6.677955627441406,6.757646083831787,6.760474681854248,5.9973907470703125,6.595290660858154,7.230656623840332,7.153912544250488,7.150241851806641,7.139529228210449,6.588026523590088,7.474699020385742,7.986477851867676,8.06174373626709,7.9634904861450195,8.02121639251709,7.962072849273682,7.179314613342285,7.040990352630615,7.048347473144531,6.612026691436768,6.821392059326172,6.917796611785889,6.924925804138184,6.870512962341309,4.1537675857543945,4.041611671447754,4.052206993103027,6.549182891845703,6.801236629486084,6.460076808929443,6.295151710510254,5.536218643188477,6.036147117614746,7.200414180755615,6.86285400390625,7.163132190704346,6.594761848449707,5.759495735168457,10.180872917175293,10.221125602722168,10.233226776123047,10.249805450439453,10.286480903625488,10.734200477600098,10.790465354919434,11.196102142333984,11.038025856018066,11.27739429473877,11.853018760681152,11.289806365966797,11.734622955322266,11.693033218383789,5.171178817749023,4.817994117736816,4.810859203338623,4.608697891235352,4.420729160308838,2.3554420471191406,1.6296287775039673,1.5856802463531494,1.5744954347610474,1.7072185277938843,-0.2656899094581604,-0.0015653264708817005,0.41186365485191345,0.07206705957651138,9.642864227294922,9.66828727722168,9.659465789794922,9.655130386352539,9.646818161010742,9.70325756072998,9.684815406799316,9.667333602905273,9.65034294128418,9.658228874206543,9.638404846191406,9.589401245117188,9.753083229064941,9.77857780456543,5.727268695831299,5.3762922286987305,5.367572784423828,4.476753234863281,4.704709529876709,4.791475296020508,7.4384284019470215,7.3892822265625,7.567340850830078,6.300681114196777,6.1241655349731445,5.4726786613464355,5.190304279327393,3.8241045475006104,6.356189727783203,6.317603588104248,6.32591438293457,6.336987018585205,6.298388481140137,6.271337509155273,6.2714643478393555,6.309792518615723,6.805884838104248,7.704934120178223,7.15537166595459,7.055767059326172,7.094388008117676,7.06955623626709,3.549379348754883,3.5916616916656494,3.5909056663513184,3.6571645736694336,3.7122726440429688,3.7132368087768555,3.8178927898406982,4.086890697479248,4.490044116973877,4.372595310211182,4.3311262130737305,4.464758396148682,6.260718822479248,6.250090599060059,11.673582077026367,11.719518661499023,11.685579299926758,11.66911506652832,11.709715843200684,11.650923728942871,11.575181007385254,11.065431594848633,10.881431579589844,10.985991477966309,10.905095100402832,10.857202529907227,10.730655670166016,10.698346138000488,10.509601593017578,10.52554702758789,10.536133766174316,10.276969909667969,10.225785255432129,10.241697311401367,10.266562461853027,10.618830680847168,10.625202178955078,10.834415435791016,10.801828384399414,10.840753555297852,10.528238296508789,10.508660316467285,4.673623561859131,4.679968357086182,4.696391582489014,4.777462959289551,4.840827941894531,5.170201778411865,5.360241889953613,5.556809902191162,6.14040994644165,6.321874618530273,6.374418258666992,6.116969108581543,6.2399582862854,6.231536388397217,3.9824554920196533,3.992987871170044,3.959887981414795,4.102766990661621,4.41977071762085,4.563014984130859,4.570957183837891,4.466975688934326,5.378724098205566,5.30963659286499,5.599489212036133,6.086819171905518,6.320919990539551,6.304365158081055,11.402617454528809,11.37225341796875,11.185358047485352,11.529576301574707,11.598123550415039,11.502228736877441,11.418893814086914,11.493379592895508,11.45400619506836,11.43879508972168,11.361956596374512,10.817422866821289,10.053933143615723,10.003569602966309,0.08947185426950455,0.10657942295074463,0.21638590097427368,0.4016130864620209,0.4184970557689667,0.45084619522094727,0.45014673471450806,0.44337108731269836,0.45645198225975037,0.4200596511363983,0.3170282244682312,-0.160762757062912,-0.6040794253349304,-0.473663866519928,8.403308868408203,8.384488105773926,8.397500038146973,8.14769458770752,7.865963459014893,7.668244361877441,7.795639514923096,7.296287536621094,7.714550971984863,7.547810077667236,6.811458587646484,6.808006286621094,6.713751316070557,6.634162425994873,4.855823516845703,4.915901184082031,4.920546531677246,4.810938358306885,4.907557964324951,4.853157997131348,5.1589436531066895,5.1842875480651855,5.08414888381958,5.367796421051025,5.023819923400879,5.1810078620910645,5.502784729003906,5.358598709106445,5.322297096252441,5.0285420417785645,4.8349995613098145,5.000243186950684,5.092520236968994,5.112335205078125,4.814855098724365,4.853093147277832,4.98530387878418,5.0806121826171875,5.107739448547363,5.143530368804932,5.343958377838135,5.871156692504883,3.505603075027466,3.5004868507385254,3.4970579147338867,3.532439708709717,3.51186203956604,3.54556941986084,3.4890661239624023,3.5335681438446045,3.54172420501709,3.5658211708068848,3.5522708892822266,3.566305160522461,3.5380027294158936,3.557156801223755,7.3020853996276855,6.145017623901367,6.1084771156311035,5.633564472198486,5.586700439453125,5.474312782287598,5.884582996368408,6.489935398101807,6.878068923950195,7.118383884429932,7.047299385070801,7.072510242462158,7.189340114593506,6.6743597984313965,11.61462688446045,11.629878997802734,11.648086547851563,11.370440483093262,11.382489204406738,11.610902786254883,11.582682609558105,10.918703079223633,11.264556884765625,11.296459197998047,11.342114448547363,11.384435653686523,11.208805084228516,11.365123748779297,11.707472801208496,11.629465103149414,11.678114891052246,11.63869857788086,11.652445793151855,11.610855102539063,11.629831314086914,11.628604888916016,11.430459976196289,11.40445613861084,11.428749084472656,11.47585678100586,11.428183555603027,11.441343307495117,11.07320499420166,11.068282127380371,11.172298431396484,11.661114692687988,11.800973892211914,11.83488655090332,11.794456481933594,11.852588653564453,11.801159858703613,11.242671966552734,11.874581336975098,11.330862998962402,11.384332656860352,11.911194801330566,11.42793083190918,10.881702423095703,10.479214668273926,8.870759963989258,7.48994255065918,6.825289249420166,6.531558990478516,6.479070663452148,6.969700336456299,11.584395408630371,11.655735969543457,11.615168571472168,11.62374496459961,11.635377883911133,11.21446704864502,11.20979118347168,11.215709686279297,11.197214126586914,11.193498611450195,11.586841583251953,11.640034675598145,11.64013671875,11.622132301330566,11.726935386657715,11.748664855957031,11.759187698364258,11.693243980407715,11.078341484069824,3.682783603668213,4.295785903930664,4.327033519744873,4.322961330413818,4.307363033294678,4.387834548950195,4.350818157196045,4.285233497619629,4.270446300506592,4.215364456176758,4.259326457977295,4.245090007781982,4.251669406890869,4.21579122543335,6.196788787841797,6.2252936363220215,6.175653457641602,6.191763877868652,6.117140293121338,6.147002220153809,5.332423686981201,5.492537498474121,5.4859185218811035,6.68472146987915,6.762027740478516,6.763871669769287,6.910026550292969,6.893470764160156,9.995813369750977,10.040911674499512,10.01066780090332,9.986064910888672,10.040138244628906,9.979954719543457,10.006486892700195,10.105386734008789,10.242892265319824,10.268016815185547,10.22437572479248,10.242959022521973,10.358135223388672,10.367463111877441,10.599281311035156,10.556100845336914,10.359906196594238,10.342144012451172,10.358169555664063,10.277179718017578,10.302264213562012,10.28339672088623,10.418681144714355,10.422323226928711,10.394890785217285,10.436301231384277,10.647597312927246,10.836451530456543,-3.8809397220611572,-3.8402926921844482,-3.887873411178589,-3.8991925716400146,-3.8881678581237793,-3.9150338172912598,-3.909769296646118,-3.9232022762298584,-3.9046144485473633,-3.9052212238311768,-3.882606267929077,-3.303295373916626,-3.3203725814819336,-3.2631747722625732,10.171636581420898,10.212068557739258,10.176925659179688,10.144497871398926,10.160012245178223,10.159870147705078,10.159625053405762,10.285394668579102,10.86146354675293,10.886690139770508,11.340144157409668,11.439778327941895,11.531315803527832,11.140372276306152,4.748045444488525,4.685232639312744,5.479516506195068,5.999383449554443,6.006860256195068,6.746262550354004,6.833718776702881,7.2523956298828125,6.885444164276123,6.046043872833252,5.9083991050720215,6.944026470184326,6.609475612640381,7.212624549865723,-1.205005168914795,-1.3119508028030396,-1.38824462890625,-1.414272427558899,-1.464357614517212,-1.492418885231018,-1.4720109701156616,-1.4253923892974854,-1.42830491065979,-1.4415663480758667,-1.4398372173309326,-1.4431476593017578,-1.4386183023452759,-1.1750630140304565,2.177257776260376,6.02486515045166,9.817771911621094,9.923027992248535,10.568014144897461,10.842994689941406,10.803278923034668,10.85175609588623,9.45968246459961,9.70433235168457,10.11380672454834,11.887285232543945,5.1559529304504395,9.602198600769043,10.750005722045898,10.647212028503418,10.605368614196777,9.591748237609863,8.596921920776367,7.552966117858887,4.996430397033691,4.665359973907471,4.688049793243408,4.657876491546631,4.61419677734375,4.463967323303223,4.38163423538208,4.351571559906006,9.29283332824707,9.218626976013184,9.19144058227539,8.989313125610352,7.8055853843688965,8.319994926452637,8.449786186218262,8.333446502685547,8.284236907958984,10.267403602600098,10.332630157470703,10.265615463256836,8.202515602111816,8.355936050415039,6.346394062042236,5.750355243682861,5.679010391235352,5.6815948486328125,5.677762508392334,5.989051342010498,5.9942545890808105,5.731605529785156,5.439440727233887,6.009674072265625,5.538415431976318,5.93268346786499,7.04496955871582,6.865391731262207,2.9783096313476563,3.02362322807312,3.0319061279296875,3.023454427719116,3.018369674682617,3.216301679611206,3.2173898220062256,3.3095624446868896,3.2797136306762695,3.2958807945251465,4.585046291351318,4.9722089767456055,5.871281147003174,5.37171745300293,5.284027576446533,5.268054485321045,5.2719340324401855,5.160572528839111,5.074357986450195,5.117986679077148,4.806477069854736,4.795797348022461,4.827756404876709,4.569849491119385,4.6023054122924805,4.503145694732666,4.139276027679443,4.244350433349609,1.4684315919876099,4.668633460998535,4.671708583831787,4.700383186340332,4.721953868865967,4.726337909698486,4.714666366577148,4.781314373016357,5.20800256729126,5.189837455749512,5.120697498321533,5.082742214202881,5.1419782638549805,5.139087677001953,5.845016002655029,5.893429279327393,6.310317039489746,6.259049892425537,6.346986293792725,6.200650691986084,6.501700401306152,7.3181304931640625,11.423624992370605,8.502843856811523,8.837698936462402,10.209163665771484,10.714969635009766,11.45349407196045,0.6353768706321716,0.5693467259407043,0.5271903872489929,0.5282720923423767,0.14099794626235962,0.09265939891338348,0.2771657705307007,0.4702932834625244,0.055633723735809326,0.07799533009529114,0.03954462334513664,0.05977980047464371,-0.24781237542629242,-0.2221141904592514,1.3838474750518799,1.2465931177139282,1.3285496234893799,1.5129868984222412,1.5249321460723877,1.7407904863357544,1.8960235118865967,1.9002348184585571,1.9293019771575928,1.9688310623168945,0.7375775575637817,-0.7568427920341492,-0.7164196372032166,-0.9386698603630066,5.38844108581543,5.41384220123291,5.452022552490234,5.396726608276367,5.433743000030518,5.415550708770752,4.705427169799805,4.591885566711426,4.536303520202637,4.488461494445801,4.501347541809082,4.534602165222168,4.655337333679199,4.576501369476318,3.7774345874786377,3.684612512588501,3.691584348678589,3.7000513076782227,3.580935478210449,3.633333683013916,3.694119453430176,3.52056884765625,3.5219383239746094,3.560269594192505,3.562485933303833,-0.18743205070495605,-0.47882771492004395,-0.301748126745224,-2.620544910430908,-2.570997714996338,-2.5941247940063477,-2.6740801334381104,-2.7186226844787598,-2.703489065170288,-2.7089123725891113,-2.709486722946167,-2.6838345527648926,-2.709366798400879,-2.6967074871063232,-2.711420774459839,-2.72856068611145,-2.6723387241363525,6.48606538772583,6.433925628662109,5.257501125335693,5.125468730926514,5.1847243309021,5.079347610473633,5.052597522735596,5.018689155578613,5.109124183654785,6.154954433441162,6.238729953765869,5.680357456207275,5.428542613983154,4.799074172973633,3.400442361831665,3.3800151348114014,3.360748291015625,3.3485310077667236,3.384300708770752,3.343616008758545,3.3634233474731445,3.6542248725891113,3.7650482654571533,3.629995346069336,3.735792398452759,3.75787615776062,3.576219081878662,3.701801300048828,3.1550707817077637,3.2166690826416016,3.2016358375549316,3.1825997829437256,3.169314384460449,3.171410083770752,3.171576499938965,3.1979947090148926,3.3229713439941406,3.3045616149902344,3.230585813522339,3.268193483352661,3.3924643993377686,3.3934834003448486,10.608233451843262,10.541571617126465,10.530181884765625,10.531187057495117,10.545313835144043,10.404425621032715,10.275616645812988,10.232747077941895,10.271095275878906,10.28685188293457,10.733797073364258,10.536209106445313,10.55070686340332,10.609457015991211,-3.433518409729004,-3.4203898906707764,-3.4458539485931396,-3.407717227935791,-3.420685291290283,-3.4334683418273926,-3.4307591915130615,-3.4653573036193848,-3.442615509033203,-3.4244565963745117,-3.4685933589935303,-3.4378817081451416,-3.441082000732422,-3.4430179595947266,7.095310688018799,7.128960132598877,7.190997123718262,7.267032146453857,7.232657432556152,7.195944786071777,7.333502292633057,7.874727725982666,7.324807643890381,7.258385181427002,7.220381736755371,7.087596416473389,7.010976791381836,5.198513984680176,3.2157509326934814,3.1951258182525635,3.271975040435791,3.1282052993774414,3.1307570934295654,3.1749353408813477,3.2519662380218506,11.24990463256836,11.673966407775879,11.624591827392578,11.38920783996582,11.469534873962402,11.277486801147461,11.140657424926758,10.569117546081543,10.524096488952637,10.638348579406738,11.010769844055176,10.672148704528809,10.715508460998535,10.458791732788086,10.489883422851563,10.680177688598633,11.164955139160156,11.253231048583984,11.2011079788208,11.210634231567383,11.648290634155273,7.8322577476501465,7.832911014556885,5.49753475189209,4.299740791320801,7.8337202072143555,9.866236686706543,9.944441795349121,9.889644622802734,9.948739051818848,10.072181701660156,10.18472671508789,10.123923301696777,5.935841083526611,7.5691022872924805,9.192455291748047,9.220964431762695,8.899893760681152,8.470431327819824,8.45925235748291,8.474715232849121,8.392083168029785,8.202069282531738,8.300753593444824,8.275469779968262,8.266131401062012,8.429534912109375,8.450687408447266,8.78325366973877,1.5559037923812866,1.5547351837158203,1.5366029739379883,1.5193933248519897,1.5414621829986572,1.5753180980682373,1.5200012922286987,1.5988726615905762,1.5540603399276733,1.5775103569030762,1.5498125553131104,1.8328003883361816,4.455596923828125,4.561614990234375,7.4848103523254395,10.165654182434082,10.092977523803711,9.868889808654785,9.884764671325684,9.8839111328125,9.805779457092285,9.804271697998047,10.283609390258789,9.89815616607666,7.57118558883667,8.099862098693848,7.424132347106934,6.226841449737549,-0.2910028398036957,-0.2948369085788727,-0.35103777050971985,-0.3715825080871582,-0.3833099603652954,-0.42302191257476807,-0.3775459825992584,-0.01547855231910944,2.6340747717767954E-4,0.09805414825677872,0.019211245700716972,0.13005214929580688,0.18664321303367615,0.1471036970615387,-2.7087104320526123,-0.09219390898942947,6.103702068328857,10.211925506591797,4.3625640869140625,4.4214677810668945,4.418032646179199,4.246175289154053,4.118462085723877,4.143425941467285,4.066636562347412,3.0870182514190674,2.7162578105926514,2.4641194343566895,2.7657856941223145,2.9837002754211426,2.9825334548950195,3.86361026763916,8.799097061157227,9.188081741333008,9.203047752380371,9.185879707336426,9.425982475280762,9.251395225524902,9.258377075195313,9.20059585571289,9.22668170928955,9.076276779174805,11.384475708007813,10.787951469421387,10.850675582885742,11.119909286499023,11.215005874633789,11.890960693359375,11.732783317565918,11.333841323852539,11.209470748901367,11.281539916992188,10.639358520507813,8.736214637756348,8.723796844482422,9.593293190002441,11.2377290725708,11.21759033203125,11.20739459991455,11.075590133666992,11.038290023803711,10.339131355285645,10.343767166137695,10.427728652954102,11.088017463684082,11.342265129089355,11.394268989562988,11.4204740524292,11.362359046936035,11.638615608215332,4.0788702964782715,4.044857501983643,4.095630168914795,4.263281345367432,4.307191371917725,4.2077436447143555,4.196568012237549,4.264021396636963,4.3712897300720215,4.6818060874938965,4.182216644287109,4.081780433654785,3.952789783477783,3.957056760787964,3.5551915168762207,3.5586678981781006,3.5283868312835693,3.5472123622894287,3.5607500076293945,3.55936861038208,3.531275987625122,3.5642518997192383,3.541184663772583,3.546125888824463,3.4981822967529297,3.2778358459472656,3.2199933528900146,2.774024248123169,0.9208897352218628,1.0644780397415161,0.73160719871521,0.636759340763092,0.6611807346343994,0.6686099171638489,0.6138471961021423,0.7128393650054932,0.5092943906784058,0.4596008360385895,0.5267395973205566,0.6119752526283264,0.5814053416252136,0.7182450294494629,7.497651100158691,7.441154479980469,7.558741569519043,8.200382232666016,8.163565635681152,11.186342239379883,11.24817943572998,11.339539527893066,11.34083080291748,11.721945762634277,10.892931938171387,11.215356826782227,11.539643287658691,11.496217727661133,0.10253982990980148,0.0792071744799614,0.09404461085796356,0.07816673070192337,0.09488744288682938,0.1320202797651291,0.14878800511360168,0.08535870909690857,0.14339646697044373,0.20249319076538086,0.15905317664146423,0.027098000049591064,0.11212272197008133,0.18969421088695526,0.8315567970275879,0.8242456316947937,0.703456461429596,0.013326674699783325,-0.042018771171569824,-0.532660186290741,-0.7757664322853088,-0.7772085666656494,-0.8220218420028687,-0.8828127384185791,-0.731307864189148,-0.733935534954071,-0.8590861558914185,-0.803728461265564,7.615827560424805,7.683978080749512,7.645866870880127,7.760718822479248,7.84836483001709,7.862738609313965,7.849540710449219,7.779909610748291,7.767083644866943,7.5334601402282715,8.996442794799805,8.148877143859863,8.19118595123291,7.598452568054199,9.53296947479248,9.48967170715332,9.519079208374023,9.703288078308105,9.73387336730957,9.46869945526123,9.56338882446289,9.597551345825195,9.67859935760498,9.69329833984375,9.584983825683594,9.494006156921387,9.503361701965332,9.430912017822266,-1.4938640594482422,-1.4557822942733765,-1.5185939073562622,-1.5811177492141724,-1.5569207668304443,-1.5873162746429443,-1.5498929023742676,-1.5599638223648071,-1.556978702545166,-1.562233805656433,-1.5421109199523926,-1.548026204109192,-1.5121651887893677,-1.563285231590271,0.3692018389701843,0.2936341464519501,0.38014984130859375,-0.106206513941288,-0.10330772399902344,-0.1993488073348999,-0.16160249710083008,-0.16463641822338104,-0.6331295371055603,-0.18320780992507935,-0.29838627576828003,-0.17579960823059082,-0.1669313758611679,-0.16713693737983704,8.40798568725586,8.989174842834473,9.005621910095215,7.808358192443848,7.823842525482178,7.826329231262207,7.763622283935547,7.999630451202393,7.473900318145752,7.499260425567627,7.482853889465332,7.850341796875,7.879006385803223,7.809985637664795,-1.2394461631774902,-1.2676619291305542,-1.2781559228897095,-1.1973116397857666,-1.2568553686141968,-1.210525631904602,-1.2085539102554321,-0.3957843780517578,0.0033307725097984076,0.28384947776794434,0.348747581243515,0.40102729201316833,0.4559231996536255,0.7505748867988586,5.76761531829834,5.845480918884277,5.8352131843566895,5.1187310218811035,5.197696208953857,5.119075298309326,5.918503761291504,5.843236923217773,5.948566913604736,5.921480178833008,5.9514689445495605,6.850861549377441,7.229028224945068,7.15781831741333,1.4483025074005127,-0.7219157814979553,-0.9453117847442627,-1.1445794105529785,-1.1183462142944336,-1.5353469848632813,-1.5183852910995483,-1.560301661491394,-1.5881556272506714,-1.5902891159057617,-1.5929728746414185,-1.5718762874603271,-1.5456159114837646,-1.444933295249939,11.606136322021484,11.606549263000488,11.603715896606445,11.595200538635254,11.597576141357422,11.646514892578125,11.622678756713867,11.597189903259277,11.596389770507813,11.617776870727539,11.564937591552734,11.561979293823242,11.591395378112793,11.60407543182373,4.665369987487793,4.683843612670898,4.67014741897583,4.488099098205566,4.4973978996276855,4.488337993621826,4.610316753387451,4.614126205444336,4.6051554679870605,4.7070231437683105,5.216418266296387,5.1761155128479,5.148379325866699,5.191099166870117,11.050769805908203,11.049250602722168,11.015497207641602,10.86655330657959,10.833398818969727,10.801732063293457,10.801533699035645,10.799327850341797,10.55566120147705,10.52915096282959,10.449722290039063,10.477298736572266,10.593194961547852,10.517786026000977,10.874430656433105,10.823390007019043,10.817914962768555,10.462953567504883,10.343884468078613,10.445601463317871,10.350563049316406,10.645251274108887,10.743301391601563,10.79175853729248,10.751879692077637,10.352861404418945,10.027203559875488,10.470643997192383,8.952071189880371,9.342409133911133,9.28226089477539,10.137582778930664,10.10324764251709,8.35912799835205,8.138724327087402,7.257748603820801,6.7215070724487305,5.093875885009766,4.742674350738525,4.751718044281006,4.686408519744873,4.530303478240967,7.747413635253906,7.621333122253418,7.18536901473999,7.158631324768066,7.106700420379639,7.354567050933838,8.708285331726074,9.09720516204834,9.053139686584473,9.044825553894043,8.803930282592773,9.064237594604492,9.299700736999512,9.374489784240723,-0.41690942645072937,-0.4546716511249542,-0.40066128969192505,-0.40829524397850037,-0.44080108404159546,-0.4427928328514099,-0.3972633183002472,-0.40632033348083496,-0.23898392915725708,-0.12394067645072937,-0.18835024535655975,-0.19094650447368622,-0.21433398127555847,-0.2095804214477539,7.699797630310059,7.6881422996521,7.709210395812988,7.634800434112549,7.703220367431641,7.664862155914307,7.658859729766846,7.87468147277832,7.941464424133301,7.891081809997559,8.479231834411621,8.914419174194336,9.28863525390625,9.345658302307129,6.049930095672607,5.871168613433838,5.850362300872803,6.695382118225098,7.2035322189331055,7.179637908935547,7.259131908416748,7.823953151702881,8.25413703918457,8.388009071350098,8.242082595825195,8.476845741271973,7.296741962432861,6.835488319396973,3.129223585128784,3.142775774002075,3.1578099727630615,3.1450555324554443,3.1438350677490234,3.12762451171875,3.131995916366577,3.1708362102508545,3.126798629760742,3.185499906539917,3.204012632369995,3.2742297649383545,3.174643039703369,3.1797194480895996,-0.5824922323226929,-0.517879843711853,-0.5125371813774109,-0.48606812953948975,-0.4506761431694031,-0.4386551082134247,-0.4660678803920746,-0.5162216424942017,-0.5343960523605347,-0.5027085542678833,-0.5460464954376221,-0.5756680965423584,-0.574657142162323,-0.4722711145877838,5.349454402923584,5.405770301818848,5.416175842285156,5.417940616607666,5.483669281005859,5.1675567626953125,4.068124294281006,4.032622337341309,3.9999616146087646,5.013892650604248,5.0809712409973145,5.094986438751221,5.131723403930664,5.079510688781738,0.323476642370224,0.29017162322998047,0.40878206491470337,0.455593079328537,1.084193468093872,7.722837448120117,7.70356559753418,7.764153480529785,7.748785495758057,7.653371334075928,7.70915412902832,7.705076694488525,7.682465553283691,11.071246147155762,5.538844585418701,5.4990129470825195,5.56205415725708,5.535508632659912,5.566179275512695,6.342169284820557,6.410648822784424,6.33814001083374,5.94354772567749,5.861940860748291,5.939225673675537,6.116643905639648,6.128077507019043,6.436376571655273,5.623895645141602,5.568116664886475,5.7992119789123535,6.121855735778809,6.064673900604248,5.595419406890869,5.661955833435059,5.706831932067871,5.950382709503174,5.859005451202393,7.692037105560303,8.737178802490234,8.730612754821777,8.856101989746094,11.027702331542969,10.980764389038086,11.060271263122559,11.032519340515137,11.073959350585938,10.798279762268066,10.664161682128906,10.70019817352295,10.701163291931152,10.807909965515137,11.217700004577637,10.778164863586426,10.572901725769043,10.430257797241211,3.370614767074585,3.371128559112549,3.352874279022217,3.3255813121795654,3.3399100303649902,3.2792866230010986,3.2640366554260254,3.230445384979248,3.2345094680786133,3.234734058380127,3.5285537242889404,1.087085485458374,0.4295955002307892,0.33888834714889526,5.165658473968506,5.194076061248779,5.275606632232666,5.736841201782227,5.782032012939453,5.641088008880615,5.693503379821777,5.781065940856934,5.30106258392334,5.947866916656494,5.9873948097229,6.897547721862793,7.260626316070557,7.231273651123047,9.717060089111328,9.621341705322266,9.677188873291016,9.675827980041504,9.646415710449219,9.753684043884277,9.745157241821289,10.061891555786133,10.268287658691406,10.19133186340332,9.821269989013672,9.614130973815918,9.701481819152832,9.809237480163574,3.2342731952667236,3.2492921352386475,3.2351834774017334,3.240860939025879,3.235708236694336,3.244539499282837,3.228816270828247,3.276364803314209,3.19608998298645,3.2252886295318604,3.221130609512329,3.2040212154388428,3.214919090270996,3.245577096939087,6.687413215637207,6.8104472160339355,6.935754776000977,7.227285385131836,6.565392971038818,6.325531959533691,6.84669303894043,7.202281475067139,7.015447616577148,6.645063877105713,7.0626702308654785,7.364538669586182,7.3524603843688965,7.430344581604004,5.542694091796875,5.552102088928223,5.576883316040039,5.650115489959717,5.7383809089660645,5.550014019012451,5.4884796142578125,5.481740474700928,5.652285099029541,5.56473970413208,5.874571323394775,5.860098361968994,6.826121807098389,6.8786139488220215,10.704120635986328,10.399012565612793,9.988971710205078,9.325284957885742,9.1978120803833,9.127790451049805,9.187243461608887,10.959073066711426,10.895975112915039,10.866682052612305,10.852248191833496,10.866735458374023,10.799173355102539,10.71022891998291,6.182521343231201,6.147538661956787,6.128333568572998,6.148126602172852,6.16339635848999,6.158756256103516,6.1464128494262695,6.165201663970947,9.868292808532715,10.25629711151123,9.653509140014648,9.559511184692383,9.867513656616211,10.629518508911133,8.261429786682129,8.245914459228516,8.3041353225708,8.633090019226074,8.720215797424316,8.647465705871582,8.636746406555176,8.672796249389648,8.704041481018066,8.663680076599121,8.653829574584961,8.625815391540527,8.580426216125488,8.63005256652832,9.676030158996582,9.646809577941895,9.623940467834473,9.669708251953125,10.15243148803711,9.772957801818848,9.778284072875977,9.742120742797852,9.71988582611084,10.681779861450195,11.83623218536377,11.570718765258789,11.020939826965332,10.749488830566406,11.297182083129883,11.27525806427002,11.300135612487793,10.90706729888916,10.828988075256348,10.801878929138184,10.804088592529297,10.71211051940918,10.747474670410156,10.641487121582031,10.889315605163574,11.417296409606934,11.290316581726074,11.840191841125488,3.787355422973633,3.645498752593994,3.7083473205566406,3.750082015991211,3.754838228225708,3.7154760360717773,3.7160608768463135,3.7308619022369385,3.690065860748291,3.701554775238037,3.774172067642212,4.114424705505371,4.435132026672363,4.47791862487793,3.965193033218384,4.0134124755859375,4.0182013511657715,5.0392746925354,4.7729716300964355,4.090211868286133,4.091414451599121,4.353031158447266,5.072195529937744,5.016704559326172,5.42197847366333,5.379803657531738,5.333767414093018,5.347291946411133,0.5650243759155273,0.984199047088623,1.0203579664230347,1.0451843738555908,1.0460630655288696,1.028517246246338,1.0517144203186035,1.0352298021316528,1.0672192573547363,1.050460934638977,1.0363562107086182,1.0527875423431396,1.0311208963394165,1.0481592416763306,11.153956413269043,11.064350128173828,11.17747974395752,11.212332725524902,11.178545951843262,11.234570503234863,11.177545547485352,11.246247291564941,11.26801586151123,11.273064613342285,11.380568504333496,11.467366218566895,11.476587295532227,11.529902458190918,10.346356391906738,10.35538387298584,10.446110725402832,10.410083770751953,10.40502643585205,9.901402473449707,9.240547180175781,10.485905647277832,10.501835823059082,8.750761032104492,7.389866352081299,8.62436580657959,10.270137786865234,10.518192291259766,11.124255180358887,11.125511169433594,11.15526294708252,11.1643705368042,11.13697338104248,10.976237297058105,11.138385772705078,11.137560844421387,11.092684745788574,10.630119323730469,10.854735374450684,10.899225234985352,11.125086784362793,11.125753402709961,-5.019455432891846,-5.006584644317627,-4.990108966827393,-5.006624698638916,-5.0173211097717285,-5.031138896942139,-5.02284049987793,-5.029787063598633,-5.032192707061768,-5.017479419708252,-5.013908386230469,-5.010448455810547,-5.022459030151367,-5.029394149780273,11.214481353759766,11.185096740722656,11.300308227539063,11.320732116699219,10.570255279541016,10.333992004394531,10.017587661743164,8.288496971130371,7.715282440185547,8.07861328125,6.785641193389893,6.300257205963135,6.955563545227051,7.07097053527832,10.19604778289795,10.192065238952637,10.175826072692871,10.194135665893555,10.2803955078125,10.439817428588867,11.86343002319336,11.896294593811035,11.864143371582031,11.892895698547363,11.795938491821289,11.522482872009277,11.636828422546387,11.593043327331543,3.407151222229004,3.414074420928955,3.413139581680298,3.425799608230591,3.4005863666534424,3.4115335941314697,3.4109113216400146,3.4112014770507813,3.421992778778076,3.4174225330352783,3.4109177589416504,3.393998384475708,3.4201698303222656,3.417419195175171,5.609394550323486,5.548037528991699,5.669188022613525,6.317144870758057,6.255722522735596,6.232303142547607,6.365804672241211,6.581195831298828,7.303200721740723,6.5674309730529785,6.511845111846924,6.6927618980407715,6.9952592849731445,7.1622514724731445,3.4794981479644775,3.658693790435791,4.372257709503174,4.812222480773926,4.793148994445801,4.710421085357666,5.063295841217041,6.133110046386719,6.676310062408447,7.15065336227417,8.666047096252441,9.304277420043945,7.427130222320557,8.645519256591797,11.673541069030762,11.740019798278809,11.755145072937012,11.706136703491211,11.769207954406738,11.74704647064209,11.76453685760498,11.689967155456543,11.708025932312012,11.570988655090332,11.604398727416992,11.653518676757813,11.634613037109375,11.662113189697266,10.474994659423828,10.463652610778809,10.452625274658203,10.449070930480957,10.404938697814941,10.396567344665527,9.753105163574219,9.69254207611084,9.724101066589355,9.77549934387207,9.864080429077148,9.583149909973145,9.577515602111816,9.551197052001953,-3.422668933868408,-3.3462681770324707,-3.327770471572876,-3.3191070556640625,-3.342203140258789,-3.3304672241210938,-3.3184077739715576,-3.3186323642730713,-3.308791399002075,-3.3238115310668945,-3.2981960773468018,-3.302340030670166,-3.3056514263153076,-3.2497246265411377,7.807676315307617,8.58487319946289,8.658960342407227,10.025443077087402,10.642960548400879,11.172032356262207,11.072412490844727,11.488872528076172,10.956284523010254,10.852898597717285,10.701373100280762,10.56987476348877,10.348604202270508,10.044934272766113,5.891895771026611,6.207301139831543,6.249152183532715,6.234323978424072,6.2090535163879395,5.493819236755371,4.478906154632568,4.4698486328125,4.43353796005249,4.428251266479492,4.401007652282715,4.425382614135742,4.477344036102295,4.532902717590332],\n",
       "\"country_year\":[\"Mexico-2010\",\"Mexico-2011\",\"Mexico-2012\",\"Mexico-2013\",\"Mexico-2014\",\"Mexico-2015\",\"Mexico-2016\",\"Mexico-2017\",\"Mexico-2018\",\"Mexico-2019\",\"Mexico-2020\",\"Mexico-2021\",\"Mexico-2022\",\"Mexico-2023\",\"Suriname-2010\",\"Suriname-2011\",\"Suriname-2012\",\"Suriname-2013\",\"Suriname-2014\",\"Suriname-2015\",\"Suriname-2016\",\"Suriname-2017\",\"Suriname-2018\",\"Suriname-2019\",\"Suriname-2020\",\"Suriname-2021\",\"Suriname-2022\",\"Suriname-2023\",\"Sweden-2010\",\"Sweden-2011\",\"Sweden-2012\",\"Sweden-2013\",\"Sweden-2014\",\"Sweden-2015\",\"Sweden-2016\",\"Sweden-2017\",\"Sweden-2018\",\"Sweden-2019\",\"Sweden-2020\",\"Sweden-2021\",\"Sweden-2022\",\"Sweden-2023\",\"Switzerland-2010\",\"Switzerland-2011\",\"Switzerland-2012\",\"Switzerland-2013\",\"Switzerland-2014\",\"Switzerland-2015\",\"Switzerland-2016\",\"Switzerland-2017\",\"Switzerland-2018\",\"Switzerland-2019\",\"Switzerland-2020\",\"Switzerland-2021\",\"Switzerland-2022\",\"Switzerland-2023\",\"Ghana-2010\",\"Ghana-2011\",\"Ghana-2012\",\"Ghana-2013\",\"Ghana-2014\",\"Ghana-2015\",\"Ghana-2016\",\"Ghana-2017\",\"Ghana-2018\",\"Ghana-2019\",\"Ghana-2020\",\"Ghana-2021\",\"Ghana-2022\",\"Ghana-2023\",\"South Africa-2010\",\"South Africa-2011\",\"South Africa-2012\",\"South Africa-2013\",\"South Africa-2014\",\"South Africa-2015\",\"South Africa-2016\",\"South Africa-2017\",\"South Africa-2018\",\"South Africa-2019\",\"South Africa-2020\",\"South Africa-2021\",\"South Africa-2022\",\"South Africa-2023\",\"Japan-2010\",\"Japan-2011\",\"Japan-2012\",\"Japan-2013\",\"Japan-2014\",\"Japan-2015\",\"Japan-2016\",\"Japan-2017\",\"Japan-2018\",\"Japan-2019\",\"Japan-2020\",\"Japan-2021\",\"Japan-2022\",\"Japan-2023\",\"Burma/Myanmar-2010\",\"Burma/Myanmar-2011\",\"Burma/Myanmar-2012\",\"Burma/Myanmar-2013\",\"Burma/Myanmar-2014\",\"Burma/Myanmar-2015\",\"Burma/Myanmar-2016\",\"Burma/Myanmar-2017\",\"Burma/Myanmar-2018\",\"Burma/Myanmar-2019\",\"Burma/Myanmar-2020\",\"Burma/Myanmar-2021\",\"Burma/Myanmar-2022\",\"Burma/Myanmar-2023\",\"Russia-2010\",\"Russia-2011\",\"Russia-2012\",\"Russia-2013\",\"Russia-2014\",\"Russia-2015\",\"Russia-2016\",\"Russia-2017\",\"Russia-2018\",\"Russia-2019\",\"Russia-2020\",\"Russia-2021\",\"Russia-2022\",\"Russia-2023\",\"Albania-2010\",\"Albania-2011\",\"Albania-2012\",\"Albania-2013\",\"Albania-2014\",\"Albania-2015\",\"Albania-2016\",\"Albania-2017\",\"Albania-2018\",\"Albania-2019\",\"Albania-2020\",\"Albania-2021\",\"Albania-2022\",\"Albania-2023\",\"Egypt-2010\",\"Egypt-2011\",\"Egypt-2012\",\"Egypt-2013\",\"Egypt-2014\",\"Egypt-2015\",\"Egypt-2016\",\"Egypt-2017\",\"Egypt-2018\",\"Egypt-2019\",\"Egypt-2020\",\"Egypt-2021\",\"Egypt-2022\",\"Egypt-2023\",\"Yemen-2010\",\"Yemen-2011\",\"Yemen-2012\",\"Yemen-2013\",\"Yemen-2014\",\"Yemen-2015\",\"Yemen-2016\",\"Yemen-2017\",\"Yemen-2018\",\"Yemen-2019\",\"Yemen-2020\",\"Yemen-2021\",\"Yemen-2022\",\"Yemen-2023\",\"Colombia-2010\",\"Colombia-2011\",\"Colombia-2012\",\"Colombia-2013\",\"Colombia-2014\",\"Colombia-2015\",\"Colombia-2016\",\"Colombia-2017\",\"Colombia-2018\",\"Colombia-2019\",\"Colombia-2020\",\"Colombia-2021\",\"Colombia-2022\",\"Colombia-2023\",\"Poland-2010\",\"Poland-2011\",\"Poland-2012\",\"Poland-2013\",\"Poland-2014\",\"Poland-2015\",\"Poland-2016\",\"Poland-2017\",\"Poland-2018\",\"Poland-2019\",\"Poland-2020\",\"Poland-2021\",\"Poland-2022\",\"Poland-2023\",\"Brazil-2010\",\"Brazil-2011\",\"Brazil-2012\",\"Brazil-2013\",\"Brazil-2014\",\"Brazil-2015\",\"Brazil-2016\",\"Brazil-2017\",\"Brazil-2018\",\"Brazil-2019\",\"Brazil-2020\",\"Brazil-2021\",\"Brazil-2022\",\"Brazil-2023\",\"United States of America-2010\",\"United States of America-2011\",\"United States of America-2012\",\"United States of America-2013\",\"United States of America-2014\",\"United States of America-2015\",\"United States of America-2016\",\"United States of America-2017\",\"United States of America-2018\",\"United States of America-2019\",\"United States of America-2020\",\"United States of America-2021\",\"United States of America-2022\",\"United States of America-2023\",\"Portugal-2010\",\"Portugal-2011\",\"Portugal-2012\",\"Portugal-2013\",\"Portugal-2014\",\"Portugal-2015\",\"Portugal-2016\",\"Portugal-2017\",\"Portugal-2018\",\"Portugal-2019\",\"Portugal-2020\",\"Portugal-2021\",\"Portugal-2022\",\"Portugal-2023\",\"El Salvador-2010\",\"El Salvador-2011\",\"El Salvador-2012\",\"El Salvador-2013\",\"El Salvador-2014\",\"El Salvador-2015\",\"El Salvador-2016\",\"El Salvador-2017\",\"El Salvador-2018\",\"El Salvador-2019\",\"El Salvador-2020\",\"El Salvador-2021\",\"El Salvador-2022\",\"El Salvador-2023\",\"Bangladesh-2010\",\"Bangladesh-2011\",\"Bangladesh-2012\",\"Bangladesh-2013\",\"Bangladesh-2014\",\"Bangladesh-2015\",\"Bangladesh-2016\",\"Bangladesh-2017\",\"Bangladesh-2018\",\"Bangladesh-2019\",\"Bangladesh-2020\",\"Bangladesh-2021\",\"Bangladesh-2022\",\"Bangladesh-2023\",\"Bolivia-2010\",\"Bolivia-2011\",\"Bolivia-2012\",\"Bolivia-2013\",\"Bolivia-2014\",\"Bolivia-2015\",\"Bolivia-2016\",\"Bolivia-2017\",\"Bolivia-2018\",\"Bolivia-2019\",\"Bolivia-2020\",\"Bolivia-2021\",\"Bolivia-2022\",\"Bolivia-2023\",\"Haiti-2010\",\"Haiti-2011\",\"Haiti-2012\",\"Haiti-2013\",\"Haiti-2014\",\"Haiti-2015\",\"Haiti-2016\",\"Haiti-2017\",\"Haiti-2018\",\"Haiti-2019\",\"Haiti-2020\",\"Haiti-2021\",\"Haiti-2022\",\"Haiti-2023\",\"Honduras-2010\",\"Honduras-2011\",\"Honduras-2012\",\"Honduras-2013\",\"Honduras-2014\",\"Honduras-2015\",\"Honduras-2016\",\"Honduras-2017\",\"Honduras-2018\",\"Honduras-2019\",\"Honduras-2020\",\"Honduras-2021\",\"Honduras-2022\",\"Honduras-2023\",\"Mali-2010\",\"Mali-2011\",\"Mali-2012\",\"Mali-2013\",\"Mali-2014\",\"Mali-2015\",\"Mali-2016\",\"Mali-2017\",\"Mali-2018\",\"Mali-2019\",\"Mali-2020\",\"Mali-2021\",\"Mali-2022\",\"Mali-2023\",\"Pakistan-2010\",\"Pakistan-2011\",\"Pakistan-2012\",\"Pakistan-2013\",\"Pakistan-2014\",\"Pakistan-2015\",\"Pakistan-2016\",\"Pakistan-2017\",\"Pakistan-2018\",\"Pakistan-2019\",\"Pakistan-2020\",\"Pakistan-2021\",\"Pakistan-2022\",\"Pakistan-2023\",\"Peru-2010\",\"Peru-2011\",\"Peru-2012\",\"Peru-2013\",\"Peru-2014\",\"Peru-2015\",\"Peru-2016\",\"Peru-2017\",\"Peru-2018\",\"Peru-2019\",\"Peru-2020\",\"Peru-2021\",\"Peru-2022\",\"Peru-2023\",\"Senegal-2010\",\"Senegal-2011\",\"Senegal-2012\",\"Senegal-2013\",\"Senegal-2014\",\"Senegal-2015\",\"Senegal-2016\",\"Senegal-2017\",\"Senegal-2018\",\"Senegal-2019\",\"Senegal-2020\",\"Senegal-2021\",\"Senegal-2022\",\"Senegal-2023\",\"South Sudan-2011\",\"South Sudan-2012\",\"South Sudan-2013\",\"South Sudan-2014\",\"South Sudan-2015\",\"South Sudan-2016\",\"South Sudan-2017\",\"South Sudan-2018\",\"South Sudan-2019\",\"South Sudan-2020\",\"South Sudan-2021\",\"South Sudan-2022\",\"South Sudan-2023\",\"Sudan-2010\",\"Sudan-2011\",\"Sudan-2012\",\"Sudan-2013\",\"Sudan-2014\",\"Sudan-2015\",\"Sudan-2016\",\"Sudan-2017\",\"Sudan-2018\",\"Sudan-2019\",\"Sudan-2020\",\"Sudan-2021\",\"Sudan-2022\",\"Sudan-2023\",\"Vietnam-2010\",\"Vietnam-2011\",\"Vietnam-2012\",\"Vietnam-2013\",\"Vietnam-2014\",\"Vietnam-2015\",\"Vietnam-2016\",\"Vietnam-2017\",\"Vietnam-2018\",\"Vietnam-2019\",\"Vietnam-2020\",\"Vietnam-2021\",\"Vietnam-2022\",\"Vietnam-2023\",\"Afghanistan-2010\",\"Afghanistan-2011\",\"Afghanistan-2012\",\"Afghanistan-2013\",\"Afghanistan-2014\",\"Afghanistan-2015\",\"Afghanistan-2016\",\"Afghanistan-2017\",\"Afghanistan-2018\",\"Afghanistan-2019\",\"Afghanistan-2020\",\"Afghanistan-2021\",\"Afghanistan-2022\",\"Afghanistan-2023\",\"Argentina-2010\",\"Argentina-2011\",\"Argentina-2012\",\"Argentina-2013\",\"Argentina-2014\",\"Argentina-2015\",\"Argentina-2016\",\"Argentina-2017\",\"Argentina-2018\",\"Argentina-2019\",\"Argentina-2020\",\"Argentina-2021\",\"Argentina-2022\",\"Argentina-2023\",\"Ethiopia-2010\",\"Ethiopia-2011\",\"Ethiopia-2012\",\"Ethiopia-2013\",\"Ethiopia-2014\",\"Ethiopia-2015\",\"Ethiopia-2016\",\"Ethiopia-2017\",\"Ethiopia-2018\",\"Ethiopia-2019\",\"Ethiopia-2020\",\"Ethiopia-2021\",\"Ethiopia-2022\",\"Ethiopia-2023\",\"India-2010\",\"India-2011\",\"India-2012\",\"India-2013\",\"India-2014\",\"India-2015\",\"India-2016\",\"India-2017\",\"India-2018\",\"India-2019\",\"India-2020\",\"India-2021\",\"India-2022\",\"India-2023\",\"Kenya-2010\",\"Kenya-2011\",\"Kenya-2012\",\"Kenya-2013\",\"Kenya-2014\",\"Kenya-2015\",\"Kenya-2016\",\"Kenya-2017\",\"Kenya-2018\",\"Kenya-2019\",\"Kenya-2020\",\"Kenya-2021\",\"Kenya-2022\",\"Kenya-2023\",\"North Korea-2010\",\"North Korea-2011\",\"North Korea-2012\",\"North Korea-2013\",\"North Korea-2014\",\"North Korea-2015\",\"North Korea-2016\",\"North Korea-2017\",\"North Korea-2018\",\"North Korea-2019\",\"North Korea-2020\",\"North Korea-2021\",\"North Korea-2022\",\"North Korea-2023\",\"South Korea-2010\",\"South Korea-2011\",\"South Korea-2012\",\"South Korea-2013\",\"South Korea-2014\",\"South Korea-2015\",\"South Korea-2016\",\"South Korea-2017\",\"South Korea-2018\",\"South Korea-2019\",\"South Korea-2020\",\"South Korea-2021\",\"South Korea-2022\",\"South Korea-2023\",\"Kosovo-2010\",\"Kosovo-2011\",\"Kosovo-2012\",\"Kosovo-2013\",\"Kosovo-2014\",\"Kosovo-2015\",\"Kosovo-2016\",\"Kosovo-2017\",\"Kosovo-2018\",\"Kosovo-2019\",\"Kosovo-2020\",\"Kosovo-2021\",\"Kosovo-2022\",\"Kosovo-2023\",\"Lebanon-2010\",\"Lebanon-2011\",\"Lebanon-2012\",\"Lebanon-2013\",\"Lebanon-2014\",\"Lebanon-2015\",\"Lebanon-2016\",\"Lebanon-2017\",\"Lebanon-2018\",\"Lebanon-2019\",\"Lebanon-2020\",\"Lebanon-2021\",\"Lebanon-2022\",\"Lebanon-2023\",\"Nigeria-2010\",\"Nigeria-2011\",\"Nigeria-2012\",\"Nigeria-2013\",\"Nigeria-2014\",\"Nigeria-2015\",\"Nigeria-2016\",\"Nigeria-2017\",\"Nigeria-2018\",\"Nigeria-2019\",\"Nigeria-2020\",\"Nigeria-2021\",\"Nigeria-2022\",\"Nigeria-2023\",\"Philippines-2010\",\"Philippines-2011\",\"Philippines-2012\",\"Philippines-2013\",\"Philippines-2014\",\"Philippines-2015\",\"Philippines-2016\",\"Philippines-2017\",\"Philippines-2018\",\"Philippines-2019\",\"Philippines-2020\",\"Philippines-2021\",\"Philippines-2022\",\"Philippines-2023\",\"Tanzania-2010\",\"Tanzania-2011\",\"Tanzania-2012\",\"Tanzania-2013\",\"Tanzania-2014\",\"Tanzania-2015\",\"Tanzania-2016\",\"Tanzania-2017\",\"Tanzania-2018\",\"Tanzania-2019\",\"Tanzania-2020\",\"Tanzania-2021\",\"Tanzania-2022\",\"Tanzania-2023\",\"Taiwan-2010\",\"Taiwan-2011\",\"Taiwan-2012\",\"Taiwan-2013\",\"Taiwan-2014\",\"Taiwan-2015\",\"Taiwan-2016\",\"Taiwan-2017\",\"Taiwan-2018\",\"Taiwan-2019\",\"Taiwan-2020\",\"Taiwan-2021\",\"Taiwan-2022\",\"Taiwan-2023\",\"Thailand-2010\",\"Thailand-2011\",\"Thailand-2012\",\"Thailand-2013\",\"Thailand-2014\",\"Thailand-2015\",\"Thailand-2016\",\"Thailand-2017\",\"Thailand-2018\",\"Thailand-2019\",\"Thailand-2020\",\"Thailand-2021\",\"Thailand-2022\",\"Thailand-2023\",\"Uganda-2010\",\"Uganda-2011\",\"Uganda-2012\",\"Uganda-2013\",\"Uganda-2014\",\"Uganda-2015\",\"Uganda-2016\",\"Uganda-2017\",\"Uganda-2018\",\"Uganda-2019\",\"Uganda-2020\",\"Uganda-2021\",\"Uganda-2022\",\"Uganda-2023\",\"Venezuela-2010\",\"Venezuela-2011\",\"Venezuela-2012\",\"Venezuela-2013\",\"Venezuela-2014\",\"Venezuela-2015\",\"Venezuela-2016\",\"Venezuela-2017\",\"Venezuela-2018\",\"Venezuela-2019\",\"Venezuela-2020\",\"Venezuela-2021\",\"Venezuela-2022\",\"Venezuela-2023\",\"Benin-2010\",\"Benin-2011\",\"Benin-2012\",\"Benin-2013\",\"Benin-2014\",\"Benin-2015\",\"Benin-2016\",\"Benin-2017\",\"Benin-2018\",\"Benin-2019\",\"Benin-2020\",\"Benin-2021\",\"Benin-2022\",\"Benin-2023\",\"Bhutan-2010\",\"Bhutan-2011\",\"Bhutan-2012\",\"Bhutan-2013\",\"Bhutan-2014\",\"Bhutan-2015\",\"Bhutan-2016\",\"Bhutan-2017\",\"Bhutan-2018\",\"Bhutan-2019\",\"Bhutan-2020\",\"Bhutan-2021\",\"Bhutan-2022\",\"Bhutan-2023\",\"Burkina Faso-2010\",\"Burkina Faso-2011\",\"Burkina Faso-2012\",\"Burkina Faso-2013\",\"Burkina Faso-2014\",\"Burkina Faso-2015\",\"Burkina Faso-2016\",\"Burkina Faso-2017\",\"Burkina Faso-2018\",\"Burkina Faso-2019\",\"Burkina Faso-2020\",\"Burkina Faso-2021\",\"Burkina Faso-2022\",\"Burkina Faso-2023\",\"Cambodia-2010\",\"Cambodia-2011\",\"Cambodia-2012\",\"Cambodia-2013\",\"Cambodia-2014\",\"Cambodia-2015\",\"Cambodia-2016\",\"Cambodia-2017\",\"Cambodia-2018\",\"Cambodia-2019\",\"Cambodia-2020\",\"Cambodia-2021\",\"Cambodia-2022\",\"Cambodia-2023\",\"Indonesia-2010\",\"Indonesia-2011\",\"Indonesia-2012\",\"Indonesia-2013\",\"Indonesia-2014\",\"Indonesia-2015\",\"Indonesia-2016\",\"Indonesia-2017\",\"Indonesia-2018\",\"Indonesia-2019\",\"Indonesia-2020\",\"Indonesia-2021\",\"Indonesia-2022\",\"Indonesia-2023\",\"Mozambique-2010\",\"Mozambique-2011\",\"Mozambique-2012\",\"Mozambique-2013\",\"Mozambique-2014\",\"Mozambique-2015\",\"Mozambique-2016\",\"Mozambique-2017\",\"Mozambique-2018\",\"Mozambique-2019\",\"Mozambique-2020\",\"Mozambique-2021\",\"Mozambique-2022\",\"Mozambique-2023\",\"Nepal-2010\",\"Nepal-2011\",\"Nepal-2012\",\"Nepal-2013\",\"Nepal-2014\",\"Nepal-2015\",\"Nepal-2016\",\"Nepal-2017\",\"Nepal-2018\",\"Nepal-2019\",\"Nepal-2020\",\"Nepal-2021\",\"Nepal-2022\",\"Nepal-2023\",\"Nicaragua-2010\",\"Nicaragua-2011\",\"Nicaragua-2012\",\"Nicaragua-2013\",\"Nicaragua-2014\",\"Nicaragua-2015\",\"Nicaragua-2016\",\"Nicaragua-2017\",\"Nicaragua-2018\",\"Nicaragua-2019\",\"Nicaragua-2020\",\"Nicaragua-2021\",\"Nicaragua-2022\",\"Nicaragua-2023\",\"Niger-2010\",\"Niger-2011\",\"Niger-2012\",\"Niger-2013\",\"Niger-2014\",\"Niger-2015\",\"Niger-2016\",\"Niger-2017\",\"Niger-2018\",\"Niger-2019\",\"Niger-2020\",\"Niger-2021\",\"Niger-2022\",\"Niger-2023\",\"Zambia-2010\",\"Zambia-2011\",\"Zambia-2012\",\"Zambia-2013\",\"Zambia-2014\",\"Zambia-2015\",\"Zambia-2016\",\"Zambia-2017\",\"Zambia-2018\",\"Zambia-2019\",\"Zambia-2020\",\"Zambia-2021\",\"Zambia-2022\",\"Zambia-2023\",\"Zimbabwe-2010\",\"Zimbabwe-2011\",\"Zimbabwe-2012\",\"Zimbabwe-2013\",\"Zimbabwe-2014\",\"Zimbabwe-2015\",\"Zimbabwe-2016\",\"Zimbabwe-2017\",\"Zimbabwe-2018\",\"Zimbabwe-2019\",\"Zimbabwe-2020\",\"Zimbabwe-2021\",\"Zimbabwe-2022\",\"Zimbabwe-2023\",\"Guinea-2010\",\"Guinea-2011\",\"Guinea-2012\",\"Guinea-2013\",\"Guinea-2014\",\"Guinea-2015\",\"Guinea-2016\",\"Guinea-2017\",\"Guinea-2018\",\"Guinea-2019\",\"Guinea-2020\",\"Guinea-2021\",\"Guinea-2022\",\"Guinea-2023\",\"Ivory Coast-2010\",\"Ivory Coast-2011\",\"Ivory Coast-2012\",\"Ivory Coast-2013\",\"Ivory Coast-2014\",\"Ivory Coast-2015\",\"Ivory Coast-2016\",\"Ivory Coast-2017\",\"Ivory Coast-2018\",\"Ivory Coast-2019\",\"Ivory Coast-2020\",\"Ivory Coast-2021\",\"Ivory Coast-2022\",\"Ivory Coast-2023\",\"Mauritania-2010\",\"Mauritania-2011\",\"Mauritania-2012\",\"Mauritania-2013\",\"Mauritania-2014\",\"Mauritania-2015\",\"Mauritania-2016\",\"Mauritania-2017\",\"Mauritania-2018\",\"Mauritania-2019\",\"Mauritania-2020\",\"Mauritania-2021\",\"Mauritania-2022\",\"Mauritania-2023\",\"Canada-2010\",\"Canada-2011\",\"Canada-2012\",\"Canada-2013\",\"Canada-2014\",\"Canada-2015\",\"Canada-2016\",\"Canada-2017\",\"Canada-2018\",\"Canada-2019\",\"Canada-2020\",\"Canada-2021\",\"Canada-2022\",\"Canada-2023\",\"Australia-2010\",\"Australia-2011\",\"Australia-2012\",\"Australia-2013\",\"Australia-2014\",\"Australia-2015\",\"Australia-2016\",\"Australia-2017\",\"Australia-2018\",\"Australia-2019\",\"Australia-2020\",\"Australia-2021\",\"Australia-2022\",\"Australia-2023\",\"Botswana-2010\",\"Botswana-2011\",\"Botswana-2012\",\"Botswana-2013\",\"Botswana-2014\",\"Botswana-2015\",\"Botswana-2016\",\"Botswana-2017\",\"Botswana-2018\",\"Botswana-2019\",\"Botswana-2020\",\"Botswana-2021\",\"Botswana-2022\",\"Botswana-2023\",\"Burundi-2010\",\"Burundi-2011\",\"Burundi-2012\",\"Burundi-2013\",\"Burundi-2014\",\"Burundi-2015\",\"Burundi-2016\",\"Burundi-2017\",\"Burundi-2018\",\"Burundi-2019\",\"Burundi-2020\",\"Burundi-2021\",\"Burundi-2022\",\"Burundi-2023\",\"Cape Verde-2010\",\"Cape Verde-2011\",\"Cape Verde-2012\",\"Cape Verde-2013\",\"Cape Verde-2014\",\"Cape Verde-2015\",\"Cape Verde-2016\",\"Cape Verde-2017\",\"Cape Verde-2018\",\"Cape Verde-2019\",\"Cape Verde-2020\",\"Cape Verde-2021\",\"Cape Verde-2022\",\"Cape Verde-2023\",\"Central African Republic-2010\",\"Central African Republic-2011\",\"Central African Republic-2012\",\"Central African Republic-2013\",\"Central African Republic-2014\",\"Central African Republic-2015\",\"Central African Republic-2016\",\"Central African Republic-2017\",\"Central African Republic-2018\",\"Central African Republic-2019\",\"Central African Republic-2020\",\"Central African Republic-2021\",\"Central African Republic-2022\",\"Central African Republic-2023\",\"Chile-2010\",\"Chile-2011\",\"Chile-2012\",\"Chile-2013\",\"Chile-2014\",\"Chile-2015\",\"Chile-2016\",\"Chile-2017\",\"Chile-2018\",\"Chile-2019\",\"Chile-2020\",\"Chile-2021\",\"Chile-2022\",\"Chile-2023\",\"Costa Rica-2010\",\"Costa Rica-2011\",\"Costa Rica-2012\",\"Costa Rica-2013\",\"Costa Rica-2014\",\"Costa Rica-2015\",\"Costa Rica-2016\",\"Costa Rica-2017\",\"Costa Rica-2018\",\"Costa Rica-2019\",\"Costa Rica-2020\",\"Costa Rica-2021\",\"Costa Rica-2022\",\"Costa Rica-2023\",\"Timor-Leste-2010\",\"Timor-Leste-2011\",\"Timor-Leste-2012\",\"Timor-Leste-2013\",\"Timor-Leste-2014\",\"Timor-Leste-2015\",\"Timor-Leste-2016\",\"Timor-Leste-2017\",\"Timor-Leste-2018\",\"Timor-Leste-2019\",\"Timor-Leste-2020\",\"Timor-Leste-2021\",\"Timor-Leste-2022\",\"Timor-Leste-2023\",\"Ecuador-2010\",\"Ecuador-2011\",\"Ecuador-2012\",\"Ecuador-2013\",\"Ecuador-2014\",\"Ecuador-2015\",\"Ecuador-2016\",\"Ecuador-2017\",\"Ecuador-2018\",\"Ecuador-2019\",\"Ecuador-2020\",\"Ecuador-2021\",\"Ecuador-2022\",\"Ecuador-2023\",\"France-2010\",\"France-2011\",\"France-2012\",\"France-2013\",\"France-2014\",\"France-2015\",\"France-2016\",\"France-2017\",\"France-2018\",\"France-2019\",\"France-2020\",\"France-2021\",\"France-2022\",\"France-2023\",\"Germany-2010\",\"Germany-2011\",\"Germany-2012\",\"Germany-2013\",\"Germany-2014\",\"Germany-2015\",\"Germany-2016\",\"Germany-2017\",\"Germany-2018\",\"Germany-2019\",\"Germany-2020\",\"Germany-2021\",\"Germany-2022\",\"Germany-2023\",\"Guatemala-2010\",\"Guatemala-2011\",\"Guatemala-2012\",\"Guatemala-2013\",\"Guatemala-2014\",\"Guatemala-2015\",\"Guatemala-2016\",\"Guatemala-2017\",\"Guatemala-2018\",\"Guatemala-2019\",\"Guatemala-2020\",\"Guatemala-2021\",\"Guatemala-2022\",\"Guatemala-2023\",\"Iran-2010\",\"Iran-2011\",\"Iran-2012\",\"Iran-2013\",\"Iran-2014\",\"Iran-2015\",\"Iran-2016\",\"Iran-2017\",\"Iran-2018\",\"Iran-2019\",\"Iran-2020\",\"Iran-2021\",\"Iran-2022\",\"Iran-2023\",\"Iraq-2010\",\"Iraq-2011\",\"Iraq-2012\",\"Iraq-2013\",\"Iraq-2014\",\"Iraq-2015\",\"Iraq-2016\",\"Iraq-2017\",\"Iraq-2018\",\"Iraq-2019\",\"Iraq-2020\",\"Iraq-2021\",\"Iraq-2022\",\"Iraq-2023\",\"Ireland-2010\",\"Ireland-2011\",\"Ireland-2012\",\"Ireland-2013\",\"Ireland-2014\",\"Ireland-2015\",\"Ireland-2016\",\"Ireland-2017\",\"Ireland-2018\",\"Ireland-2019\",\"Ireland-2020\",\"Ireland-2021\",\"Ireland-2022\",\"Ireland-2023\",\"Italy-2010\",\"Italy-2011\",\"Italy-2012\",\"Italy-2013\",\"Italy-2014\",\"Italy-2015\",\"Italy-2016\",\"Italy-2017\",\"Italy-2018\",\"Italy-2019\",\"Italy-2020\",\"Italy-2021\",\"Italy-2022\",\"Italy-2023\",\"Jordan-2010\",\"Jordan-2011\",\"Jordan-2012\",\"Jordan-2013\",\"Jordan-2014\",\"Jordan-2015\",\"Jordan-2016\",\"Jordan-2017\",\"Jordan-2018\",\"Jordan-2019\",\"Jordan-2020\",\"Jordan-2021\",\"Jordan-2022\",\"Jordan-2023\",\"Latvia-2010\",\"Latvia-2011\",\"Latvia-2012\",\"Latvia-2013\",\"Latvia-2014\",\"Latvia-2015\",\"Latvia-2016\",\"Latvia-2017\",\"Latvia-2018\",\"Latvia-2019\",\"Latvia-2020\",\"Latvia-2021\",\"Latvia-2022\",\"Latvia-2023\",\"Lesotho-2010\",\"Lesotho-2011\",\"Lesotho-2012\",\"Lesotho-2013\",\"Lesotho-2014\",\"Lesotho-2015\",\"Lesotho-2016\",\"Lesotho-2017\",\"Lesotho-2018\",\"Lesotho-2019\",\"Lesotho-2020\",\"Lesotho-2021\",\"Lesotho-2022\",\"Lesotho-2023\",\"Liberia-2010\",\"Liberia-2011\",\"Liberia-2012\",\"Liberia-2013\",\"Liberia-2014\",\"Liberia-2015\",\"Liberia-2016\",\"Liberia-2017\",\"Liberia-2018\",\"Liberia-2019\",\"Liberia-2020\",\"Liberia-2021\",\"Liberia-2022\",\"Liberia-2023\",\"Malawi-2010\",\"Malawi-2011\",\"Malawi-2012\",\"Malawi-2013\",\"Malawi-2014\",\"Malawi-2015\",\"Malawi-2016\",\"Malawi-2017\",\"Malawi-2018\",\"Malawi-2019\",\"Malawi-2020\",\"Malawi-2021\",\"Malawi-2022\",\"Malawi-2023\",\"Maldives-2010\",\"Maldives-2011\",\"Maldives-2012\",\"Maldives-2013\",\"Maldives-2014\",\"Maldives-2015\",\"Maldives-2016\",\"Maldives-2017\",\"Maldives-2018\",\"Maldives-2019\",\"Maldives-2020\",\"Maldives-2021\",\"Maldives-2022\",\"Maldives-2023\",\"Mongolia-2010\",\"Mongolia-2011\",\"Mongolia-2012\",\"Mongolia-2013\",\"Mongolia-2014\",\"Mongolia-2015\",\"Mongolia-2016\",\"Mongolia-2017\",\"Mongolia-2018\",\"Mongolia-2019\",\"Mongolia-2020\",\"Mongolia-2021\",\"Mongolia-2022\",\"Mongolia-2023\",\"Morocco-2010\",\"Morocco-2011\",\"Morocco-2012\",\"Morocco-2013\",\"Morocco-2014\",\"Morocco-2015\",\"Morocco-2016\",\"Morocco-2017\",\"Morocco-2018\",\"Morocco-2019\",\"Morocco-2020\",\"Morocco-2021\",\"Morocco-2022\",\"Morocco-2023\",\"Netherlands-2010\",\"Netherlands-2011\",\"Netherlands-2012\",\"Netherlands-2013\",\"Netherlands-2014\",\"Netherlands-2015\",\"Netherlands-2016\",\"Netherlands-2017\",\"Netherlands-2018\",\"Netherlands-2019\",\"Netherlands-2020\",\"Netherlands-2021\",\"Netherlands-2022\",\"Netherlands-2023\",\"Panama-2010\",\"Panama-2011\",\"Panama-2012\",\"Panama-2013\",\"Panama-2014\",\"Panama-2015\",\"Panama-2016\",\"Panama-2017\",\"Panama-2018\",\"Panama-2019\",\"Panama-2020\",\"Panama-2021\",\"Panama-2022\",\"Panama-2023\",\"Papua New Guinea-2010\",\"Papua New Guinea-2011\",\"Papua New Guinea-2012\",\"Papua New Guinea-2013\",\"Papua New Guinea-2014\",\"Papua New Guinea-2015\",\"Papua New Guinea-2016\",\"Papua New Guinea-2017\",\"Papua New Guinea-2018\",\"Papua New Guinea-2019\",\"Papua New Guinea-2020\",\"Papua New Guinea-2021\",\"Papua New Guinea-2022\",\"Papua New Guinea-2023\",\"Qatar-2010\",\"Qatar-2011\",\"Qatar-2012\",\"Qatar-2013\",\"Qatar-2014\",\"Qatar-2015\",\"Qatar-2016\",\"Qatar-2017\",\"Qatar-2018\",\"Qatar-2019\",\"Qatar-2020\",\"Qatar-2021\",\"Qatar-2022\",\"Qatar-2023\",\"Sierra Leone-2010\",\"Sierra Leone-2011\",\"Sierra Leone-2012\",\"Sierra Leone-2013\",\"Sierra Leone-2014\",\"Sierra Leone-2015\",\"Sierra Leone-2016\",\"Sierra Leone-2017\",\"Sierra Leone-2018\",\"Sierra Leone-2019\",\"Sierra Leone-2020\",\"Sierra Leone-2021\",\"Sierra Leone-2022\",\"Sierra Leone-2023\",\"Spain-2010\",\"Spain-2011\",\"Spain-2012\",\"Spain-2013\",\"Spain-2014\",\"Spain-2015\",\"Spain-2016\",\"Spain-2017\",\"Spain-2018\",\"Spain-2019\",\"Spain-2020\",\"Spain-2021\",\"Spain-2022\",\"Spain-2023\",\"Syria-2010\",\"Syria-2011\",\"Syria-2012\",\"Syria-2013\",\"Syria-2014\",\"Syria-2015\",\"Syria-2016\",\"Syria-2017\",\"Syria-2018\",\"Syria-2019\",\"Syria-2020\",\"Syria-2021\",\"Syria-2022\",\"Syria-2023\",\"Tunisia-2010\",\"Tunisia-2011\",\"Tunisia-2012\",\"Tunisia-2013\",\"Tunisia-2014\",\"Tunisia-2015\",\"Tunisia-2016\",\"Tunisia-2017\",\"Tunisia-2018\",\"Tunisia-2019\",\"Tunisia-2020\",\"Tunisia-2021\",\"Tunisia-2022\",\"Tunisia-2023\",\"Türkiye-2010\",\"Türkiye-2011\",\"Türkiye-2012\",\"Türkiye-2013\",\"Türkiye-2014\",\"Türkiye-2015\",\"Türkiye-2016\",\"Türkiye-2017\",\"Türkiye-2018\",\"Türkiye-2019\",\"Türkiye-2020\",\"Türkiye-2021\",\"Türkiye-2022\",\"Türkiye-2023\",\"Ukraine-2010\",\"Ukraine-2011\",\"Ukraine-2012\",\"Ukraine-2013\",\"Ukraine-2014\",\"Ukraine-2015\",\"Ukraine-2016\",\"Ukraine-2017\",\"Ukraine-2018\",\"Ukraine-2019\",\"Ukraine-2020\",\"Ukraine-2021\",\"Ukraine-2022\",\"Ukraine-2023\",\"United Kingdom-2010\",\"United Kingdom-2011\",\"United Kingdom-2012\",\"United Kingdom-2013\",\"United Kingdom-2014\",\"United Kingdom-2015\",\"United Kingdom-2016\",\"United Kingdom-2017\",\"United Kingdom-2018\",\"United Kingdom-2019\",\"United Kingdom-2020\",\"United Kingdom-2021\",\"United Kingdom-2022\",\"United Kingdom-2023\",\"Uruguay-2010\",\"Uruguay-2011\",\"Uruguay-2012\",\"Uruguay-2013\",\"Uruguay-2014\",\"Uruguay-2015\",\"Uruguay-2016\",\"Uruguay-2017\",\"Uruguay-2018\",\"Uruguay-2019\",\"Uruguay-2020\",\"Uruguay-2021\",\"Uruguay-2022\",\"Uruguay-2023\",\"Algeria-2010\",\"Algeria-2011\",\"Algeria-2012\",\"Algeria-2013\",\"Algeria-2014\",\"Algeria-2015\",\"Algeria-2016\",\"Algeria-2017\",\"Algeria-2018\",\"Algeria-2019\",\"Algeria-2020\",\"Algeria-2021\",\"Algeria-2022\",\"Algeria-2023\",\"Angola-2010\",\"Angola-2011\",\"Angola-2012\",\"Angola-2013\",\"Angola-2014\",\"Angola-2015\",\"Angola-2016\",\"Angola-2017\",\"Angola-2018\",\"Angola-2019\",\"Angola-2020\",\"Angola-2021\",\"Angola-2022\",\"Angola-2023\",\"Armenia-2010\",\"Armenia-2011\",\"Armenia-2012\",\"Armenia-2013\",\"Armenia-2014\",\"Armenia-2015\",\"Armenia-2016\",\"Armenia-2017\",\"Armenia-2018\",\"Armenia-2019\",\"Armenia-2020\",\"Armenia-2021\",\"Armenia-2022\",\"Armenia-2023\",\"Azerbaijan-2010\",\"Azerbaijan-2011\",\"Azerbaijan-2012\",\"Azerbaijan-2013\",\"Azerbaijan-2014\",\"Azerbaijan-2015\",\"Azerbaijan-2016\",\"Azerbaijan-2017\",\"Azerbaijan-2018\",\"Azerbaijan-2019\",\"Azerbaijan-2020\",\"Azerbaijan-2021\",\"Azerbaijan-2022\",\"Azerbaijan-2023\",\"Belarus-2010\",\"Belarus-2011\",\"Belarus-2012\",\"Belarus-2013\",\"Belarus-2014\",\"Belarus-2015\",\"Belarus-2016\",\"Belarus-2017\",\"Belarus-2018\",\"Belarus-2019\",\"Belarus-2020\",\"Belarus-2021\",\"Belarus-2022\",\"Belarus-2023\",\"Cameroon-2010\",\"Cameroon-2011\",\"Cameroon-2012\",\"Cameroon-2013\",\"Cameroon-2014\",\"Cameroon-2015\",\"Cameroon-2016\",\"Cameroon-2017\",\"Cameroon-2018\",\"Cameroon-2019\",\"Cameroon-2020\",\"Cameroon-2021\",\"Cameroon-2022\",\"Cameroon-2023\",\"Chad-2010\",\"Chad-2011\",\"Chad-2012\",\"Chad-2013\",\"Chad-2014\",\"Chad-2015\",\"Chad-2016\",\"Chad-2017\",\"Chad-2018\",\"Chad-2019\",\"Chad-2020\",\"Chad-2021\",\"Chad-2022\",\"Chad-2023\",\"China-2010\",\"China-2011\",\"China-2012\",\"China-2013\",\"China-2014\",\"China-2015\",\"China-2016\",\"China-2017\",\"China-2018\",\"China-2019\",\"China-2020\",\"China-2021\",\"China-2022\",\"China-2023\",\"Democratic Republic of the Congo-2010\",\"Democratic Republic of the Congo-2011\",\"Democratic Republic of the Congo-2012\",\"Democratic Republic of the Congo-2013\",\"Democratic Republic of the Congo-2014\",\"Democratic Republic of the Congo-2015\",\"Democratic Republic of the Congo-2016\",\"Democratic Republic of the Congo-2017\",\"Democratic Republic of the Congo-2018\",\"Democratic Republic of the Congo-2019\",\"Democratic Republic of the Congo-2020\",\"Democratic Republic of the Congo-2021\",\"Democratic Republic of the Congo-2022\",\"Democratic Republic of the Congo-2023\",\"Republic of the Congo-2010\",\"Republic of the Congo-2011\",\"Republic of the Congo-2012\",\"Republic of the Congo-2013\",\"Republic of the Congo-2014\",\"Republic of the Congo-2015\",\"Republic of the Congo-2016\",\"Republic of the Congo-2017\",\"Republic of the Congo-2018\",\"Republic of the Congo-2019\",\"Republic of the Congo-2020\",\"Republic of the Congo-2021\",\"Republic of the Congo-2022\",\"Republic of the Congo-2023\",\"Djibouti-2010\",\"Djibouti-2011\",\"Djibouti-2012\",\"Djibouti-2013\",\"Djibouti-2014\",\"Djibouti-2015\",\"Djibouti-2016\",\"Djibouti-2017\",\"Djibouti-2018\",\"Djibouti-2019\",\"Djibouti-2020\",\"Djibouti-2021\",\"Djibouti-2022\",\"Djibouti-2023\",\"Dominican Republic-2010\",\"Dominican Republic-2011\",\"Dominican Republic-2012\",\"Dominican Republic-2013\",\"Dominican Republic-2014\",\"Dominican Republic-2015\",\"Dominican Republic-2016\",\"Dominican Republic-2017\",\"Dominican Republic-2018\",\"Dominican Republic-2019\",\"Dominican Republic-2020\",\"Dominican Republic-2021\",\"Dominican Republic-2022\",\"Dominican Republic-2023\",\"Eritrea-2010\",\"Eritrea-2011\",\"Eritrea-2012\",\"Eritrea-2013\",\"Eritrea-2014\",\"Eritrea-2015\",\"Eritrea-2016\",\"Eritrea-2017\",\"Eritrea-2018\",\"Eritrea-2019\",\"Eritrea-2020\",\"Eritrea-2021\",\"Eritrea-2022\",\"Eritrea-2023\",\"Gabon-2010\",\"Gabon-2011\",\"Gabon-2012\",\"Gabon-2013\",\"Gabon-2014\",\"Gabon-2015\",\"Gabon-2016\",\"Gabon-2017\",\"Gabon-2018\",\"Gabon-2019\",\"Gabon-2020\",\"Gabon-2021\",\"Gabon-2022\",\"Gabon-2023\",\"The Gambia-2010\",\"The Gambia-2011\",\"The Gambia-2012\",\"The Gambia-2013\",\"The Gambia-2014\",\"The Gambia-2015\",\"The Gambia-2016\",\"The Gambia-2017\",\"The Gambia-2018\",\"The Gambia-2019\",\"The Gambia-2020\",\"The Gambia-2021\",\"The Gambia-2022\",\"The Gambia-2023\",\"Georgia-2010\",\"Georgia-2011\",\"Georgia-2012\",\"Georgia-2013\",\"Georgia-2014\",\"Georgia-2015\",\"Georgia-2016\",\"Georgia-2017\",\"Georgia-2018\",\"Georgia-2019\",\"Georgia-2020\",\"Georgia-2021\",\"Georgia-2022\",\"Georgia-2023\",\"Guinea-Bissau-2010\",\"Guinea-Bissau-2011\",\"Guinea-Bissau-2012\",\"Guinea-Bissau-2013\",\"Guinea-Bissau-2014\",\"Guinea-Bissau-2015\",\"Guinea-Bissau-2016\",\"Guinea-Bissau-2017\",\"Guinea-Bissau-2018\",\"Guinea-Bissau-2019\",\"Guinea-Bissau-2020\",\"Guinea-Bissau-2021\",\"Guinea-Bissau-2022\",\"Guinea-Bissau-2023\",\"Jamaica-2010\",\"Jamaica-2011\",\"Jamaica-2012\",\"Jamaica-2013\",\"Jamaica-2014\",\"Jamaica-2015\",\"Jamaica-2016\",\"Jamaica-2017\",\"Jamaica-2018\",\"Jamaica-2019\",\"Jamaica-2020\",\"Jamaica-2021\",\"Jamaica-2022\",\"Jamaica-2023\",\"Kazakhstan-2010\",\"Kazakhstan-2011\",\"Kazakhstan-2012\",\"Kazakhstan-2013\",\"Kazakhstan-2014\",\"Kazakhstan-2015\",\"Kazakhstan-2016\",\"Kazakhstan-2017\",\"Kazakhstan-2018\",\"Kazakhstan-2019\",\"Kazakhstan-2020\",\"Kazakhstan-2021\",\"Kazakhstan-2022\",\"Kazakhstan-2023\",\"Kyrgyzstan-2010\",\"Kyrgyzstan-2011\",\"Kyrgyzstan-2012\",\"Kyrgyzstan-2013\",\"Kyrgyzstan-2014\",\"Kyrgyzstan-2015\",\"Kyrgyzstan-2016\",\"Kyrgyzstan-2017\",\"Kyrgyzstan-2018\",\"Kyrgyzstan-2019\",\"Kyrgyzstan-2020\",\"Kyrgyzstan-2021\",\"Kyrgyzstan-2022\",\"Kyrgyzstan-2023\",\"Laos-2010\",\"Laos-2011\",\"Laos-2012\",\"Laos-2013\",\"Laos-2014\",\"Laos-2015\",\"Laos-2016\",\"Laos-2017\",\"Laos-2018\",\"Laos-2019\",\"Laos-2020\",\"Laos-2021\",\"Laos-2022\",\"Laos-2023\",\"Libya-2010\",\"Libya-2011\",\"Libya-2012\",\"Libya-2013\",\"Libya-2014\",\"Libya-2015\",\"Libya-2016\",\"Libya-2017\",\"Libya-2018\",\"Libya-2019\",\"Libya-2020\",\"Libya-2021\",\"Libya-2022\",\"Libya-2023\",\"Madagascar-2010\",\"Madagascar-2011\",\"Madagascar-2012\",\"Madagascar-2013\",\"Madagascar-2014\",\"Madagascar-2015\",\"Madagascar-2016\",\"Madagascar-2017\",\"Madagascar-2018\",\"Madagascar-2019\",\"Madagascar-2020\",\"Madagascar-2021\",\"Madagascar-2022\",\"Madagascar-2023\",\"Moldova-2010\",\"Moldova-2011\",\"Moldova-2012\",\"Moldova-2013\",\"Moldova-2014\",\"Moldova-2015\",\"Moldova-2016\",\"Moldova-2017\",\"Moldova-2018\",\"Moldova-2019\",\"Moldova-2020\",\"Moldova-2021\",\"Moldova-2022\",\"Moldova-2023\",\"Namibia-2010\",\"Namibia-2011\",\"Namibia-2012\",\"Namibia-2013\",\"Namibia-2014\",\"Namibia-2015\",\"Namibia-2016\",\"Namibia-2017\",\"Namibia-2018\",\"Namibia-2019\",\"Namibia-2020\",\"Namibia-2021\",\"Namibia-2022\",\"Namibia-2023\",\"Palestine/West Bank-2010\",\"Palestine/West Bank-2011\",\"Palestine/West Bank-2012\",\"Palestine/West Bank-2013\",\"Palestine/West Bank-2014\",\"Palestine/West Bank-2015\",\"Palestine/West Bank-2016\",\"Palestine/West Bank-2017\",\"Palestine/West Bank-2018\",\"Palestine/West Bank-2019\",\"Palestine/West Bank-2020\",\"Palestine/West Bank-2021\",\"Palestine/West Bank-2022\",\"Palestine/West Bank-2023\",\"Rwanda-2010\",\"Rwanda-2011\",\"Rwanda-2012\",\"Rwanda-2013\",\"Rwanda-2014\",\"Rwanda-2015\",\"Rwanda-2016\",\"Rwanda-2017\",\"Rwanda-2018\",\"Rwanda-2019\",\"Rwanda-2020\",\"Rwanda-2021\",\"Rwanda-2022\",\"Rwanda-2023\",\"Somalia-2010\",\"Somalia-2011\",\"Somalia-2012\",\"Somalia-2013\",\"Somalia-2014\",\"Somalia-2015\",\"Somalia-2016\",\"Somalia-2017\",\"Somalia-2018\",\"Somalia-2019\",\"Somalia-2020\",\"Somalia-2021\",\"Somalia-2022\",\"Somalia-2023\",\"Sri Lanka-2010\",\"Sri Lanka-2011\",\"Sri Lanka-2012\",\"Sri Lanka-2013\",\"Sri Lanka-2014\",\"Sri Lanka-2015\",\"Sri Lanka-2016\",\"Sri Lanka-2017\",\"Sri Lanka-2018\",\"Sri Lanka-2019\",\"Sri Lanka-2020\",\"Sri Lanka-2021\",\"Sri Lanka-2022\",\"Sri Lanka-2023\",\"Eswatini-2010\",\"Eswatini-2011\",\"Eswatini-2012\",\"Eswatini-2013\",\"Eswatini-2014\",\"Eswatini-2015\",\"Eswatini-2016\",\"Eswatini-2017\",\"Eswatini-2018\",\"Eswatini-2019\",\"Eswatini-2020\",\"Eswatini-2021\",\"Eswatini-2022\",\"Eswatini-2023\",\"Tajikistan-2010\",\"Tajikistan-2011\",\"Tajikistan-2012\",\"Tajikistan-2013\",\"Tajikistan-2014\",\"Tajikistan-2015\",\"Tajikistan-2016\",\"Tajikistan-2017\",\"Tajikistan-2018\",\"Tajikistan-2019\",\"Tajikistan-2020\",\"Tajikistan-2021\",\"Tajikistan-2022\",\"Tajikistan-2023\",\"Togo-2010\",\"Togo-2011\",\"Togo-2012\",\"Togo-2013\",\"Togo-2014\",\"Togo-2015\",\"Togo-2016\",\"Togo-2017\",\"Togo-2018\",\"Togo-2019\",\"Togo-2020\",\"Togo-2021\",\"Togo-2022\",\"Togo-2023\",\"Trinidad and Tobago-2010\",\"Trinidad and Tobago-2011\",\"Trinidad and Tobago-2012\",\"Trinidad and Tobago-2013\",\"Trinidad and Tobago-2014\",\"Trinidad and Tobago-2015\",\"Trinidad and Tobago-2016\",\"Trinidad and Tobago-2017\",\"Trinidad and Tobago-2018\",\"Trinidad and Tobago-2019\",\"Trinidad and Tobago-2020\",\"Trinidad and Tobago-2021\",\"Trinidad and Tobago-2022\",\"Trinidad and Tobago-2023\",\"Turkmenistan-2010\",\"Turkmenistan-2011\",\"Turkmenistan-2012\",\"Turkmenistan-2013\",\"Turkmenistan-2014\",\"Turkmenistan-2015\",\"Turkmenistan-2016\",\"Turkmenistan-2017\",\"Turkmenistan-2018\",\"Turkmenistan-2019\",\"Turkmenistan-2020\",\"Turkmenistan-2021\",\"Turkmenistan-2022\",\"Turkmenistan-2023\",\"Palestine/Gaza-2010\",\"Palestine/Gaza-2011\",\"Palestine/Gaza-2012\",\"Palestine/Gaza-2013\",\"Palestine/Gaza-2014\",\"Palestine/Gaza-2015\",\"Palestine/Gaza-2016\",\"Palestine/Gaza-2017\",\"Palestine/Gaza-2018\",\"Palestine/Gaza-2019\",\"Palestine/Gaza-2020\",\"Palestine/Gaza-2021\",\"Palestine/Gaza-2022\",\"Palestine/Gaza-2023\",\"Somaliland-2010\",\"Somaliland-2011\",\"Somaliland-2012\",\"Somaliland-2013\",\"Somaliland-2014\",\"Somaliland-2015\",\"Somaliland-2016\",\"Somaliland-2017\",\"Somaliland-2018\",\"Somaliland-2019\",\"Somaliland-2020\",\"Somaliland-2021\",\"Somaliland-2022\",\"Somaliland-2023\",\"Uzbekistan-2010\",\"Uzbekistan-2011\",\"Uzbekistan-2012\",\"Uzbekistan-2013\",\"Uzbekistan-2014\",\"Uzbekistan-2015\",\"Uzbekistan-2016\",\"Uzbekistan-2017\",\"Uzbekistan-2018\",\"Uzbekistan-2019\",\"Uzbekistan-2020\",\"Uzbekistan-2021\",\"Uzbekistan-2022\",\"Uzbekistan-2023\",\"Austria-2010\",\"Austria-2011\",\"Austria-2012\",\"Austria-2013\",\"Austria-2014\",\"Austria-2015\",\"Austria-2016\",\"Austria-2017\",\"Austria-2018\",\"Austria-2019\",\"Austria-2020\",\"Austria-2021\",\"Austria-2022\",\"Austria-2023\",\"Bahrain-2010\",\"Bahrain-2011\",\"Bahrain-2012\",\"Bahrain-2013\",\"Bahrain-2014\",\"Bahrain-2015\",\"Bahrain-2016\",\"Bahrain-2017\",\"Bahrain-2018\",\"Bahrain-2019\",\"Bahrain-2020\",\"Bahrain-2021\",\"Bahrain-2022\",\"Bahrain-2023\",\"Barbados-2010\",\"Barbados-2011\",\"Barbados-2012\",\"Barbados-2013\",\"Barbados-2014\",\"Barbados-2015\",\"Barbados-2016\",\"Barbados-2017\",\"Barbados-2018\",\"Barbados-2019\",\"Barbados-2020\",\"Barbados-2021\",\"Barbados-2022\",\"Barbados-2023\",\"Belgium-2010\",\"Belgium-2011\",\"Belgium-2012\",\"Belgium-2013\",\"Belgium-2014\",\"Belgium-2015\",\"Belgium-2016\",\"Belgium-2017\",\"Belgium-2018\",\"Belgium-2019\",\"Belgium-2020\",\"Belgium-2021\",\"Belgium-2022\",\"Belgium-2023\",\"Bosnia and Herzegovina-2010\",\"Bosnia and Herzegovina-2011\",\"Bosnia and Herzegovina-2012\",\"Bosnia and Herzegovina-2013\",\"Bosnia and Herzegovina-2014\",\"Bosnia and Herzegovina-2015\",\"Bosnia and Herzegovina-2016\",\"Bosnia and Herzegovina-2017\",\"Bosnia and Herzegovina-2018\",\"Bosnia and Herzegovina-2019\",\"Bosnia and Herzegovina-2020\",\"Bosnia and Herzegovina-2021\",\"Bosnia and Herzegovina-2022\",\"Bosnia and Herzegovina-2023\",\"Bulgaria-2010\",\"Bulgaria-2011\",\"Bulgaria-2012\",\"Bulgaria-2013\",\"Bulgaria-2014\",\"Bulgaria-2015\",\"Bulgaria-2016\",\"Bulgaria-2017\",\"Bulgaria-2018\",\"Bulgaria-2019\",\"Bulgaria-2020\",\"Bulgaria-2021\",\"Bulgaria-2022\",\"Bulgaria-2023\",\"Comoros-2010\",\"Comoros-2011\",\"Comoros-2012\",\"Comoros-2013\",\"Comoros-2014\",\"Comoros-2015\",\"Comoros-2016\",\"Comoros-2017\",\"Comoros-2018\",\"Comoros-2019\",\"Comoros-2020\",\"Comoros-2021\",\"Comoros-2022\",\"Comoros-2023\",\"Croatia-2010\",\"Croatia-2011\",\"Croatia-2012\",\"Croatia-2013\",\"Croatia-2014\",\"Croatia-2015\",\"Croatia-2016\",\"Croatia-2017\",\"Croatia-2018\",\"Croatia-2019\",\"Croatia-2020\",\"Croatia-2021\",\"Croatia-2022\",\"Croatia-2023\",\"Cuba-2010\",\"Cuba-2011\",\"Cuba-2012\",\"Cuba-2013\",\"Cuba-2014\",\"Cuba-2015\",\"Cuba-2016\",\"Cuba-2017\",\"Cuba-2018\",\"Cuba-2019\",\"Cuba-2020\",\"Cuba-2021\",\"Cuba-2022\",\"Cuba-2023\",\"Cyprus-2010\",\"Cyprus-2011\",\"Cyprus-2012\",\"Cyprus-2013\",\"Cyprus-2014\",\"Cyprus-2015\",\"Cyprus-2016\",\"Cyprus-2017\",\"Cyprus-2018\",\"Cyprus-2019\",\"Cyprus-2020\",\"Cyprus-2021\",\"Cyprus-2022\",\"Cyprus-2023\",\"Czechia-2010\",\"Czechia-2011\",\"Czechia-2012\",\"Czechia-2013\",\"Czechia-2014\",\"Czechia-2015\",\"Czechia-2016\",\"Czechia-2017\",\"Czechia-2018\",\"Czechia-2019\",\"Czechia-2020\",\"Czechia-2021\",\"Czechia-2022\",\"Czechia-2023\",\"Denmark-2010\",\"Denmark-2011\",\"Denmark-2012\",\"Denmark-2013\",\"Denmark-2014\",\"Denmark-2015\",\"Denmark-2016\",\"Denmark-2017\",\"Denmark-2018\",\"Denmark-2019\",\"Denmark-2020\",\"Denmark-2021\",\"Denmark-2022\",\"Denmark-2023\",\"Equatorial Guinea-2010\",\"Equatorial Guinea-2011\",\"Equatorial Guinea-2012\",\"Equatorial Guinea-2013\",\"Equatorial Guinea-2014\",\"Equatorial Guinea-2015\",\"Equatorial Guinea-2016\",\"Equatorial Guinea-2017\",\"Equatorial Guinea-2018\",\"Equatorial Guinea-2019\",\"Equatorial Guinea-2020\",\"Equatorial Guinea-2021\",\"Equatorial Guinea-2022\",\"Equatorial Guinea-2023\",\"Estonia-2010\",\"Estonia-2011\",\"Estonia-2012\",\"Estonia-2013\",\"Estonia-2014\",\"Estonia-2015\",\"Estonia-2016\",\"Estonia-2017\",\"Estonia-2018\",\"Estonia-2019\",\"Estonia-2020\",\"Estonia-2021\",\"Estonia-2022\",\"Estonia-2023\",\"Fiji-2010\",\"Fiji-2011\",\"Fiji-2012\",\"Fiji-2013\",\"Fiji-2014\",\"Fiji-2015\",\"Fiji-2016\",\"Fiji-2017\",\"Fiji-2018\",\"Fiji-2019\",\"Fiji-2020\",\"Fiji-2021\",\"Fiji-2022\",\"Fiji-2023\",\"Finland-2010\",\"Finland-2011\",\"Finland-2012\",\"Finland-2013\",\"Finland-2014\",\"Finland-2015\",\"Finland-2016\",\"Finland-2017\",\"Finland-2018\",\"Finland-2019\",\"Finland-2020\",\"Finland-2021\",\"Finland-2022\",\"Finland-2023\",\"Greece-2010\",\"Greece-2011\",\"Greece-2012\",\"Greece-2013\",\"Greece-2014\",\"Greece-2015\",\"Greece-2016\",\"Greece-2017\",\"Greece-2018\",\"Greece-2019\",\"Greece-2020\",\"Greece-2021\",\"Greece-2022\",\"Greece-2023\",\"Guyana-2010\",\"Guyana-2011\",\"Guyana-2012\",\"Guyana-2013\",\"Guyana-2014\",\"Guyana-2015\",\"Guyana-2016\",\"Guyana-2017\",\"Guyana-2018\",\"Guyana-2019\",\"Guyana-2020\",\"Guyana-2021\",\"Guyana-2022\",\"Guyana-2023\",\"Hong Kong-2010\",\"Hong Kong-2011\",\"Hong Kong-2012\",\"Hong Kong-2013\",\"Hong Kong-2014\",\"Hong Kong-2015\",\"Hong Kong-2016\",\"Hong Kong-2017\",\"Hong Kong-2018\",\"Hong Kong-2019\",\"Hong Kong-2020\",\"Hong Kong-2021\",\"Hong Kong-2022\",\"Hong Kong-2023\",\"Iceland-2010\",\"Iceland-2011\",\"Iceland-2012\",\"Iceland-2013\",\"Iceland-2014\",\"Iceland-2015\",\"Iceland-2016\",\"Iceland-2017\",\"Iceland-2018\",\"Iceland-2019\",\"Iceland-2020\",\"Iceland-2021\",\"Iceland-2022\",\"Iceland-2023\",\"Israel-2010\",\"Israel-2011\",\"Israel-2012\",\"Israel-2013\",\"Israel-2014\",\"Israel-2015\",\"Israel-2016\",\"Israel-2017\",\"Israel-2018\",\"Israel-2019\",\"Israel-2020\",\"Israel-2021\",\"Israel-2022\",\"Israel-2023\",\"Kuwait-2010\",\"Kuwait-2011\",\"Kuwait-2012\",\"Kuwait-2013\",\"Kuwait-2014\",\"Kuwait-2015\",\"Kuwait-2016\",\"Kuwait-2017\",\"Kuwait-2018\",\"Kuwait-2019\",\"Kuwait-2020\",\"Kuwait-2021\",\"Kuwait-2022\",\"Kuwait-2023\",\"Lithuania-2010\",\"Lithuania-2011\",\"Lithuania-2012\",\"Lithuania-2013\",\"Lithuania-2014\",\"Lithuania-2015\",\"Lithuania-2016\",\"Lithuania-2017\",\"Lithuania-2018\",\"Lithuania-2019\",\"Lithuania-2020\",\"Lithuania-2021\",\"Lithuania-2022\",\"Lithuania-2023\",\"Luxembourg-2010\",\"Luxembourg-2011\",\"Luxembourg-2012\",\"Luxembourg-2013\",\"Luxembourg-2014\",\"Luxembourg-2015\",\"Luxembourg-2016\",\"Luxembourg-2017\",\"Luxembourg-2018\",\"Luxembourg-2019\",\"Luxembourg-2020\",\"Luxembourg-2021\",\"Luxembourg-2022\",\"Luxembourg-2023\",\"North Macedonia-2010\",\"North Macedonia-2011\",\"North Macedonia-2012\",\"North Macedonia-2013\",\"North Macedonia-2014\",\"North Macedonia-2015\",\"North Macedonia-2016\",\"North Macedonia-2017\",\"North Macedonia-2018\",\"North Macedonia-2019\",\"North Macedonia-2020\",\"North Macedonia-2021\",\"North Macedonia-2022\",\"North Macedonia-2023\",\"Malaysia-2010\",\"Malaysia-2011\",\"Malaysia-2012\",\"Malaysia-2013\",\"Malaysia-2014\",\"Malaysia-2015\",\"Malaysia-2016\",\"Malaysia-2017\",\"Malaysia-2018\",\"Malaysia-2019\",\"Malaysia-2020\",\"Malaysia-2021\",\"Malaysia-2022\",\"Malaysia-2023\",\"Malta-2010\",\"Malta-2011\",\"Malta-2012\",\"Malta-2013\",\"Malta-2014\",\"Malta-2015\",\"Malta-2016\",\"Malta-2017\",\"Malta-2018\",\"Malta-2019\",\"Malta-2020\",\"Malta-2021\",\"Malta-2022\",\"Malta-2023\",\"Mauritius-2010\",\"Mauritius-2011\",\"Mauritius-2012\",\"Mauritius-2013\",\"Mauritius-2014\",\"Mauritius-2015\",\"Mauritius-2016\",\"Mauritius-2017\",\"Mauritius-2018\",\"Mauritius-2019\",\"Mauritius-2020\",\"Mauritius-2021\",\"Mauritius-2022\",\"Mauritius-2023\",\"Montenegro-2010\",\"Montenegro-2011\",\"Montenegro-2012\",\"Montenegro-2013\",\"Montenegro-2014\",\"Montenegro-2015\",\"Montenegro-2016\",\"Montenegro-2017\",\"Montenegro-2018\",\"Montenegro-2019\",\"Montenegro-2020\",\"Montenegro-2021\",\"Montenegro-2022\",\"Montenegro-2023\",\"New Zealand-2010\",\"New Zealand-2011\",\"New Zealand-2012\",\"New Zealand-2013\",\"New Zealand-2014\",\"New Zealand-2015\",\"New Zealand-2016\",\"New Zealand-2017\",\"New Zealand-2018\",\"New Zealand-2019\",\"New Zealand-2020\",\"New Zealand-2021\",\"New Zealand-2022\",\"New Zealand-2023\",\"Norway-2010\",\"Norway-2011\",\"Norway-2012\",\"Norway-2013\",\"Norway-2014\",\"Norway-2015\",\"Norway-2016\",\"Norway-2017\",\"Norway-2018\",\"Norway-2019\",\"Norway-2020\",\"Norway-2021\",\"Norway-2022\",\"Norway-2023\",\"Oman-2010\",\"Oman-2011\",\"Oman-2012\",\"Oman-2013\",\"Oman-2014\",\"Oman-2015\",\"Oman-2016\",\"Oman-2017\",\"Oman-2018\",\"Oman-2019\",\"Oman-2020\",\"Oman-2021\",\"Oman-2022\",\"Oman-2023\",\"Paraguay-2010\",\"Paraguay-2011\",\"Paraguay-2012\",\"Paraguay-2013\",\"Paraguay-2014\",\"Paraguay-2015\",\"Paraguay-2016\",\"Paraguay-2017\",\"Paraguay-2018\",\"Paraguay-2019\",\"Paraguay-2020\",\"Paraguay-2021\",\"Paraguay-2022\",\"Paraguay-2023\",\"Romania-2010\",\"Romania-2011\",\"Romania-2012\",\"Romania-2013\",\"Romania-2014\",\"Romania-2015\",\"Romania-2016\",\"Romania-2017\",\"Romania-2018\",\"Romania-2019\",\"Romania-2020\",\"Romania-2021\",\"Romania-2022\",\"Romania-2023\",\"Sao Tome and Principe-2010\",\"Sao Tome and Principe-2011\",\"Sao Tome and Principe-2012\",\"Sao Tome and Principe-2013\",\"Sao Tome and Principe-2014\",\"Sao Tome and Principe-2015\",\"Sao Tome and Principe-2016\",\"Sao Tome and Principe-2017\",\"Sao Tome and Principe-2018\",\"Sao Tome and Principe-2019\",\"Sao Tome and Principe-2020\",\"Sao Tome and Principe-2021\",\"Sao Tome and Principe-2022\",\"Sao Tome and Principe-2023\",\"Saudi Arabia-2010\",\"Saudi Arabia-2011\",\"Saudi Arabia-2012\",\"Saudi Arabia-2013\",\"Saudi Arabia-2014\",\"Saudi Arabia-2015\",\"Saudi Arabia-2016\",\"Saudi Arabia-2017\",\"Saudi Arabia-2018\",\"Saudi Arabia-2019\",\"Saudi Arabia-2020\",\"Saudi Arabia-2021\",\"Saudi Arabia-2022\",\"Saudi Arabia-2023\",\"Serbia-2010\",\"Serbia-2011\",\"Serbia-2012\",\"Serbia-2013\",\"Serbia-2014\",\"Serbia-2015\",\"Serbia-2016\",\"Serbia-2017\",\"Serbia-2018\",\"Serbia-2019\",\"Serbia-2020\",\"Serbia-2021\",\"Serbia-2022\",\"Serbia-2023\",\"Seychelles-2010\",\"Seychelles-2011\",\"Seychelles-2012\",\"Seychelles-2013\",\"Seychelles-2014\",\"Seychelles-2015\",\"Seychelles-2016\",\"Seychelles-2017\",\"Seychelles-2018\",\"Seychelles-2019\",\"Seychelles-2020\",\"Seychelles-2021\",\"Seychelles-2022\",\"Seychelles-2023\",\"Singapore-2010\",\"Singapore-2011\",\"Singapore-2012\",\"Singapore-2013\",\"Singapore-2014\",\"Singapore-2015\",\"Singapore-2016\",\"Singapore-2017\",\"Singapore-2018\",\"Singapore-2019\",\"Singapore-2020\",\"Singapore-2021\",\"Singapore-2022\",\"Singapore-2023\",\"Slovakia-2010\",\"Slovakia-2011\",\"Slovakia-2012\",\"Slovakia-2013\",\"Slovakia-2014\",\"Slovakia-2015\",\"Slovakia-2016\",\"Slovakia-2017\",\"Slovakia-2018\",\"Slovakia-2019\",\"Slovakia-2020\",\"Slovakia-2021\",\"Slovakia-2022\",\"Slovakia-2023\",\"Slovenia-2010\",\"Slovenia-2011\",\"Slovenia-2012\",\"Slovenia-2013\",\"Slovenia-2014\",\"Slovenia-2015\",\"Slovenia-2016\",\"Slovenia-2017\",\"Slovenia-2018\",\"Slovenia-2019\",\"Slovenia-2020\",\"Slovenia-2021\",\"Slovenia-2022\",\"Slovenia-2023\",\"Solomon Islands-2010\",\"Solomon Islands-2011\",\"Solomon Islands-2012\",\"Solomon Islands-2013\",\"Solomon Islands-2014\",\"Solomon Islands-2015\",\"Solomon Islands-2016\",\"Solomon Islands-2017\",\"Solomon Islands-2018\",\"Solomon Islands-2019\",\"Solomon Islands-2020\",\"Solomon Islands-2021\",\"Solomon Islands-2022\",\"Solomon Islands-2023\",\"Vanuatu-2010\",\"Vanuatu-2011\",\"Vanuatu-2012\",\"Vanuatu-2013\",\"Vanuatu-2014\",\"Vanuatu-2015\",\"Vanuatu-2016\",\"Vanuatu-2017\",\"Vanuatu-2018\",\"Vanuatu-2019\",\"Vanuatu-2020\",\"Vanuatu-2021\",\"Vanuatu-2022\",\"Vanuatu-2023\",\"United Arab Emirates-2010\",\"United Arab Emirates-2011\",\"United Arab Emirates-2012\",\"United Arab Emirates-2013\",\"United Arab Emirates-2014\",\"United Arab Emirates-2015\",\"United Arab Emirates-2016\",\"United Arab Emirates-2017\",\"United Arab Emirates-2018\",\"United Arab Emirates-2019\",\"United Arab Emirates-2020\",\"United Arab Emirates-2021\",\"United Arab Emirates-2022\",\"United Arab Emirates-2023\",\"Hungary-2010\",\"Hungary-2011\",\"Hungary-2012\",\"Hungary-2013\",\"Hungary-2014\",\"Hungary-2015\",\"Hungary-2016\",\"Hungary-2017\",\"Hungary-2018\",\"Hungary-2019\",\"Hungary-2020\",\"Hungary-2021\",\"Hungary-2022\",\"Hungary-2023\",\"Zanzibar-2010\",\"Zanzibar-2011\",\"Zanzibar-2012\",\"Zanzibar-2013\",\"Zanzibar-2014\",\"Zanzibar-2015\",\"Zanzibar-2016\",\"Zanzibar-2017\",\"Zanzibar-2018\",\"Zanzibar-2019\",\"Zanzibar-2020\",\"Zanzibar-2021\",\"Zanzibar-2022\",\"Zanzibar-2023\"],\n",
       "\"colour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n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"first_dim\",\n",
       "\"y\":\"second_dim\",\n",
       "\"colour\":\"colour\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"type\":\"float\",\n",
       "\"column\":\"first_dim\"\n",
       "},{\n",
       "\"type\":\"float\",\n",
       "\"column\":\"second_dim\"\n",
       "},{\n",
       "\"type\":\"str\",\n",
       "\"column\":\"country_year\"\n",
       "}]\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"minimal\",\n",
       "\"legend_position\":\"bottom\",\n",
       "\"panel_grid_minor\":{\n",
       "\"blank\":true\n",
       "}\n",
       "},\n",
       "\"guides\":{\n",
       "\"x\":{\n",
       "\"title\":\"First dimension\"\n",
       "},\n",
       "\"y\":{\n",
       "\"title\":\"Second dimension\"\n",
       "},\n",
       "\"colour\":{\n",
       "\"title\":\"Cluster #\"\n",
       "},\n",
       "\"shape\":{\n",
       "\"title\":\"Outlier\"\n",
       "}\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"aesthetic\":\"color\",\n",
       "\"scale_mapper_kind\":\"color_cmap\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"tooltips\":{\n",
       "\"formats\":[],\n",
       "\"lines\":[\"@country_year\"]\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[],\n",
       "\"spec_id\":\"51\"\n",
       "};\n",
       "               window.letsPlotCall(function() {\n",
       "       \n",
       "               var toolbar = null;\n",
       "               var plotContainer = containerDiv;               \n",
       "               \n",
       "                   var options = {\n",
       "                       sizing: {\n",
       "                           width_mode: \"min\",\n",
       "                           height_mode: \"scaled\",\n",
       "                           width: width\n",
       "                       }\n",
       "                   };\n",
       "                   var fig = LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer, options);\n",
       "                   if (toolbar) {\n",
       "                     toolbar.bind(fig);\n",
       "                   }\n",
       "               });\n",
       "               \n",
       "               break;\n",
       "           }\n",
       "       }\n",
       "   });\n",
       "   \n",
       "   observer.observe(containerDiv);\n",
       "   \n",
       "   // ----------\n",
       "   })();\n",
       "   \n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x1cfae7172f0>"
      ]
     },
     "execution_count": 90,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# Instantiate a dbscan \n",
    "\n",
    "\n",
    "# Fit the model to the data\n",
    "\n",
    "\n",
    "# Retrieve the labels using a list comprehension\n",
    "\n",
    "\n",
    "# Add the country_year variable in vdem to the\n",
    "\n",
    "\n",
    "# Plot the output\n",
    "\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "👥 **Classroom discussion:** Can we gain any new insights from using DBSCAN with the embeddings?"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.13.1"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
